/* $AstecId: Xrt3d_restb.c,v 1.7 1999/11/24 07:40:00 nakayama Exp $ */
/* ALL RIGHTS RESERVED
 *
 * This file is provided for demonstration and educational uses only.
 * Permission to use, copy, modify and distribute this file for
 * any purpose and without fee is hereby granted, provided that the
 * above copyright notice and this permission notice appear in all
 * copies, and that the name of KL Group not be used in advertising
 * or publicity pertaining to this material without the specific,
 * prior written permission of an authorized representative of
 * KL Group.
 *
 * KL GROUP MAKES NO REPRESENTATIONS AND EXTENDS NO WARRANTIES, EX-
 * PRESS OR IMPLIED, WITH RESPECT TO THE SOFTWARE, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR ANY PARTICULAR PURPOSE, AND THE WARRANTY AGAINST IN-
 * FRINGEMENT OF PATENTS OR OTHER INTELLECTUAL PROPERTY RIGHTS.  THE
 * SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT SHALL KL GROUP OR
 * ANY OF ITS AFFILIATES BE LIABLE FOR ANY DAMAGES, INCLUDING ANY
 * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES
 * RELATING TO THE USE OF THIS SOFTWARE.
 *
 *
 * XRT/3d widget UIM/X integration file
 *
 *  SCCSID -- @(#)Xrt3d_restb.c	1.22    99/02/01 KL Group Inc.
 */

/*****************************************************************************
				Xrt3d_restb.c
*****************************************************************************/

#include <Xm/Xrt3d.h>			/* Widget-class public header file */
#include <UxLib.h>

#ifdef DESIGN_TIME

#include "veos.h"       		/* Visual Edge object system */
#include "valuesOf.h"   		/* ValuesOf & Validator functions */

#include "Xrt3d.cl.h"

#else

#include "stub_runtime.h"

#endif /* DESIGN_TIME */

#include "Xrt3d_xtype.h"
#include "Xrt_restable.h"

extern swidget UxPopupXrt3dSurfaceData();
extern swidget UxPopupXrt3dZoneData();
extern swidget UxPopupXrt3dDistnTable();
extern swidget UxPopupXrt3dContourStyles();

extern swidget UxGUIPopupColorView();
extern swidget UxGUIPopupFontView();

static int   Xrt3dPutDouble();
static float Xrt3dGetDouble();

Xrt3dResourceDesc xrt3d_res_table[] = {
{ 
	"xrt3dAxisStrokeFont",
	"RD_xrt3dAxisStrokeFont",
	XtNxrt3dAxisStrokeFont,
	"XtNxrt3dAxisStrokeFont",
	XRT3D_UX_STROKEFONT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dAxisStrokeFont),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumAxisStrokeFont,
	FALSE,
	TRUE
},
{
	"xrt3dAxisStrokeSize",
	"RD_xrt3dAxisStrokeSize",
	XtNxrt3dAxisStrokeSize,
	"XtNxrt3dAxisStrokeSize",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dAxisStrokeSize),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumAxisStrokeSize,
	FALSE,
	TRUE
},
{
	"xrt3dAxisTitleStrokeFont",
	"RD_xrt3dAxisTitleStrokeFont",
	XtNxrt3dAxisTitleStrokeFont,
	"XtNxrt3dAxisTitleStrokeFont",
	XRT3D_UX_STROKEFONT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dAxisTitleStrokeFont),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumAxisTitleStrokeFont,
	FALSE,
	TRUE
},
{
	"xrt3dAxisTitleStrokeSize",
	"RD_xrt3dAxisTitleStrokeSize",
	XtNxrt3dAxisTitleStrokeSize,
	"XtNxrt3dAxisTitleStrokeSize",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dAxisTitleStrokeSize),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumAxisTitleStrokeSize,
	FALSE,
	TRUE
},
{
	"xrt3dBackgroundColor",
	"RD_xrt3dBackgroundColor",
	XtNxrt3dBackgroundColor,
	"XtNxrt3dBackgroundColor",
	XRT3D_UX_COLOR,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dBackgroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumBackgroundColor,
	FALSE,
	TRUE
},
{
	"xrt3dContourStyles",
	"RD_xrt3dContourStyles",
	XtNxrt3dContourStyles,
	"XtNxrt3dContourStyles",
	XRT3D_UX_CONTOURSTYLES,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dContourStyles),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumContourStyles,
	FALSE,
	TRUE
},
{
	"xrt3dDataAreaBackgroundColor",
	"RD_xrt3dDataAreaBackgroundColor",
	XtNxrt3dDataAreaBackgroundColor,
	"XtNxrt3dDataAreaBackgroundColor",
	XRT3D_UX_COLOR,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dDataAreaBackgroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumDataAreaBackgroundColor,
	FALSE,
	TRUE
},
{
	"xrt3dDebug",
	"RD_xrt3dDebug",
	XtNxrt3dDebug,
	"XtNxrt3dDebug",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dDebug),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumDebug,
	FALSE,
	TRUE
},
{
	"xrt3dDistnMethod",
	"RD_xrt3dDistnMethod",
	XtNxrt3dDistnMethod,
	"XtNxrt3dDistnMethod",
	XRT3D_UX_DISTNMETHOD,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dDistnMethod),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumDistnMethod,
	FALSE,
	TRUE
},
{
	"xrt3dDistnTable",
	"RD_xrt3dDistnTable",
	XtNxrt3dDistnTable,
	"XtNxrt3dDistnTable",
	XRT3D_UX_DISTNTABLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dDistnTable),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumDistnTable,
	FALSE,
	TRUE
},
{
	"xrt3dDoubleBuffer",
	"RD_xrt3dDoubleBuffer",
	XtNxrt3dDoubleBuffer,
	"XtNxrt3dDoubleBuffer",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dDoubleBuffer),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumDoubleBuffer,
	FALSE,
	TRUE
},
{
	"xrt3dDrawContours",
	"RD_xrt3dDrawContours",
	XtNxrt3dDrawContours,
	"XtNxrt3dDrawContours",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dDrawContours),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumDrawContours,
	FALSE,
	TRUE
},
{
	"xrt3dDrawHiddenLines",
	"RD_xrt3dDrawHiddenLines",
	XtNxrt3dDrawHiddenLines,
	"XtNxrt3dDrawHiddenLines",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dDrawHiddenLines),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumDrawHiddenLines,
	FALSE,
	TRUE
},
{
	"xrt3dDrawMesh",
	"RD_xrt3dDrawMesh",
	XtNxrt3dDrawMesh,
	"XtNxrt3dDrawMesh",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dDrawMesh),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumDrawMesh,
	FALSE,
	TRUE
},
{
	"xrt3dDrawShaded",
	"RD_xrt3dDrawShaded",
	XtNxrt3dDrawShaded,
	"XtNxrt3dDrawShaded",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dDrawShaded),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumDrawShaded,
	FALSE,
	TRUE
},
{
	"xrt3dDrawZones",
	"RD_xrt3dDrawZones",
	XtNxrt3dDrawZones,
	"XtNxrt3dDrawZones",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dDrawZones),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumDrawZones,
	FALSE,
	TRUE
},
{
	"xrt3dExposeCallback",
	"RD_xrt3dExposeCallback",
	XtNxrt3dExposeCallback,
	"XtNxrt3dExposeCallback",
	XRT3D_UX_CALLBACK,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dExposeCallback),
	XRTDIV_BEHAVIOR,
	XRTPASS0,
	NULL,
	xrt3dResNumExposeCallback,
	FALSE,
	TRUE
},
{
	"xrt3dFooterAdjust",
	"RD_xrt3dFooterAdjust",
	XtNxrt3dFooterAdjust,
	"XtNxrt3dFooterAdjust",
	XRT3D_UX_ADJUST,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dFooterAdjust),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumFooterAdjust,
	FALSE,
	TRUE
},
{
	"xrt3dFooterBackgroundColor",
	"RD_xrt3dFooterBackgroundColor",
	XtNxrt3dFooterBackgroundColor,
	"XtNxrt3dFooterBackgroundColor",
	XRT3D_UX_COLOR,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dFooterBackgroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumFooterBackgroundColor,
	FALSE,
	TRUE
},
{
	"xrt3dFooterBorder",
	"RD_xrt3dFooterBorder",
	XtNxrt3dFooterBorder,
	"XtNxrt3dFooterBorder",
	XRT3D_UX_BORDER,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dFooterBorder),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumFooterBorder,
	FALSE,
	TRUE
},
{
	"xrt3dFooterBorderWidth",
	"RD_xrt3dFooterBorderWidth",
	XtNxrt3dFooterBorderWidth,
	"XtNxrt3dFooterBorderWidth",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dFooterBorderWidth),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumFooterBorderWidth,
	FALSE,
	TRUE
},
{
	"xrt3dFooterFont",
	"RD_xrt3dFooterFont",
	XtNxrt3dFooterFont,
	"XtNxrt3dFooterFont",
	XRT3D_UX_FONT_LIST,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dFooterFont),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumFooterFont,
	FALSE,
	TRUE
},
{
	"xrt3dFooterForegroundColor",
	"RD_xrt3dFooterForegroundColor",
	XtNxrt3dFooterForegroundColor,
	"XtNxrt3dFooterForegroundColor",
	XRT3D_UX_COLOR,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dFooterForegroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumFooterForegroundColor,
	FALSE,
	TRUE
},
{
	"xrt3dFooterHeight",
	"RD_xrt3dFooterHeight",
	XtNxrt3dFooterHeight,
	"XtNxrt3dFooterHeight",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dFooterHeight),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumFooterHeight,
	TRUE,
	TRUE
},
{
	"xrt3dFooterStrings",
	"RD_xrt3dFooterStrings",
	XtNxrt3dFooterStrings,
	"XtNxrt3dFooterStrings",
	XRT3D_UX_STRINGS,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dFooterStrings),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumFooterStrings,
	FALSE,
	TRUE
},
{
	"xrt3dFooterWidth",
	"RD_xrt3dFooterWidth",
	XtNxrt3dFooterWidth,
	"XtNxrt3dFooterWidth",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dFooterWidth),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumFooterWidth,
	TRUE,
	TRUE
},
{
	"xrt3dFooterX",
	"RD_xrt3dFooterX",
	XtNxrt3dFooterX,
	"XtNxrt3dFooterX",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dFooterX),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumFooterX,
	FALSE,
	TRUE
},
{
	"xrt3dFooterXUseDefault",
	"RD_xrt3dFooterXUseDefault",
	XtNxrt3dFooterXUseDefault,
	"XtNxrt3dFooterXUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dFooterXUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumFooterXUseDefault,
	FALSE,
	TRUE
},
{
	"xrt3dFooterY",
	"RD_xrt3dFooterY",
	XtNxrt3dFooterY,
	"XtNxrt3dFooterY",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dFooterY),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumFooterY,
	FALSE,
	TRUE
},
{
	"xrt3dFooterYUseDefault",
	"RD_xrt3dFooterYUseDefault",
	XtNxrt3dFooterYUseDefault,
	"XtNxrt3dFooterYUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dFooterYUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumFooterYUseDefault,
	FALSE,
	TRUE
},
{
	"xrt3dForegroundColor",
	"RD_xrt3dForegroundColor",
	XtNxrt3dForegroundColor,
	"XtNxrt3dForegroundColor",
	XRT3D_UX_COLOR,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dForegroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumForegroundColor,
	FALSE,
	TRUE
},
{
	"xrt3dGraphBackgroundColor",
	"RD_xrt3dGraphBackgroundColor",
	XtNxrt3dGraphBackgroundColor,
	"XtNxrt3dGraphBackgroundColor",
	XRT3D_UX_COLOR,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dGraphBackgroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumGraphBackgroundColor,
	FALSE,
	TRUE
},
{
	"xrt3dGraphBorder",
	"RD_xrt3dGraphBorder",
	XtNxrt3dGraphBorder,
	"XtNxrt3dGraphBorder",
	XRT3D_UX_BORDER,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dGraphBorder),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumGraphBorder,
	FALSE,
	TRUE
},
{
	"xrt3dGraphBorderWidth",
	"RD_xrt3dGraphBorderWidth",
	XtNxrt3dGraphBorderWidth,
	"XtNxrt3dGraphBorderWidth",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dGraphBorderWidth),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumGraphBorderWidth,
	FALSE,
	TRUE
},
{
	"xrt3dGraphForegroundColor",
	"RD_xrt3dGraphForegroundColor",
	XtNxrt3dGraphForegroundColor,
	"XtNxrt3dGraphForegroundColor",
	XRT3D_UX_COLOR,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dGraphForegroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumGraphForegroundColor,
	FALSE,
	TRUE
},
{
	"xrt3dGraphHeight",
	"RD_xrt3dGraphHeight",
	XtNxrt3dGraphHeight,
	"XtNxrt3dGraphHeight",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dGraphHeight),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumGraphHeight,
	FALSE,
	TRUE
},
{
	"xrt3dGraphHeightUseDefault",
	"RD_xrt3dGraphHeightUseDefault",
	XtNxrt3dGraphHeightUseDefault,
	"XtNxrt3dGraphHeightUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dGraphHeightUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumGraphHeightUseDefault,
	FALSE,
	TRUE
},
{
	"xrt3dGraphWidth",
	"RD_xrt3dGraphWidth",
	XtNxrt3dGraphWidth,
	"XtNxrt3dGraphWidth",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dGraphWidth),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumGraphWidth,
	FALSE,
	TRUE
},
{
	"xrt3dGraphWidthUseDefault",
	"RD_xrt3dGraphWidthUseDefault",
	XtNxrt3dGraphWidthUseDefault,
	"XtNxrt3dGraphWidthUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dGraphWidthUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumGraphWidthUseDefault,
	FALSE,
	TRUE
},
{
	"xrt3dGraphX",
	"RD_xrt3dGraphX",
	XtNxrt3dGraphX,
	"XtNxrt3dGraphX",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dGraphX),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumGraphX,
	FALSE,
	TRUE
},
{
	"xrt3dGraphXUseDefault",
	"RD_xrt3dGraphXUseDefault",
	XtNxrt3dGraphXUseDefault,
	"XtNxrt3dGraphXUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dGraphXUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumGraphXUseDefault,
	FALSE,
	TRUE
},
{
	"xrt3dGraphY",
	"RD_xrt3dGraphY",
	XtNxrt3dGraphY,
	"XtNxrt3dGraphY",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dGraphY),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumGraphY,
	FALSE,
	TRUE
},
{
	"xrt3dGraphYUseDefault",
	"RD_xrt3dGraphYUseDefault",
	XtNxrt3dGraphYUseDefault,
	"XtNxrt3dGraphYUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dGraphYUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumGraphYUseDefault,
	FALSE,
	TRUE
},
{
	"xrt3dHeaderAdjust",
	"RD_xrt3dHeaderAdjust",
	XtNxrt3dHeaderAdjust,
	"XtNxrt3dHeaderAdjust",
	XRT3D_UX_ADJUST,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dHeaderAdjust),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumHeaderAdjust,
	FALSE,
	TRUE
},
{
	"xrt3dHeaderBackgroundColor",
	"RD_xrt3dHeaderBackgroundColor",
	XtNxrt3dHeaderBackgroundColor,
	"XtNxrt3dHeaderBackgroundColor",
	XRT3D_UX_COLOR,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dHeaderBackgroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumHeaderBackgroundColor,
	FALSE,
	TRUE
},
{
	"xrt3dHeaderBorder",
	"RD_xrt3dHeaderBorder",
	XtNxrt3dHeaderBorder,
	"XtNxrt3dHeaderBorder",
	XRT3D_UX_BORDER,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dHeaderBorder),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumHeaderBorder,
	FALSE,
	TRUE
},
{
	"xrt3dHeaderBorderWidth",
	"RD_xrt3dHeaderBorderWidth",
	XtNxrt3dHeaderBorderWidth,
	"XtNxrt3dHeaderBorderWidth",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dHeaderBorderWidth),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumHeaderBorderWidth,
	FALSE,
	TRUE
},
{
	"xrt3dHeaderFont",
	"RD_xrt3dHeaderFont",
	XtNxrt3dHeaderFont,
	"XtNxrt3dHeaderFont",
	XRT3D_UX_FONT_LIST,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dHeaderFont),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumHeaderFont,
	FALSE,
	TRUE
},
{
	"xrt3dHeaderForegroundColor",
	"RD_xrt3dHeaderForegroundColor",
	XtNxrt3dHeaderForegroundColor,
	"XtNxrt3dHeaderForegroundColor",
	XRT3D_UX_COLOR,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dHeaderForegroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumHeaderForegroundColor,
	FALSE,
	TRUE
},
{
	"xrt3dHeaderHeight",
	"RD_xrt3dHeaderHeight",
	XtNxrt3dHeaderHeight,
	"XtNxrt3dHeaderHeight",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dHeaderHeight),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumHeaderHeight,
	TRUE,
	TRUE
},
{
	"xrt3dHeaderStrings",
	"RD_xrt3dHeaderStrings",
	XtNxrt3dHeaderStrings,
	"XtNxrt3dHeaderStrings",
	XRT3D_UX_STRINGS,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dHeaderStrings),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumHeaderStrings,
	FALSE,
	TRUE
},
{
	"xrt3dHeaderWidth",
	"RD_xrt3dHeaderWidth",
	XtNxrt3dHeaderWidth,
	"XtNxrt3dHeaderWidth",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dHeaderWidth),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumHeaderWidth,
	TRUE,
	TRUE
},
{
	"xrt3dHeaderX",
	"RD_xrt3dHeaderX",
	XtNxrt3dHeaderX,
	"XtNxrt3dHeaderX",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dHeaderX),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumHeaderX,
	FALSE,
	TRUE
},
{
	"xrt3dHeaderXUseDefault",
	"RD_xrt3dHeaderXUseDefault",
	XtNxrt3dHeaderXUseDefault,
	"XtNxrt3dHeaderXUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dHeaderXUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumHeaderXUseDefault,
	FALSE,
	TRUE
},
{
	"xrt3dHeaderY",
	"RD_xrt3dHeaderY",
	XtNxrt3dHeaderY,
	"XtNxrt3dHeaderY",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dHeaderY),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumHeaderY,
	FALSE,
	TRUE
},
{
	"xrt3dHeaderYUseDefault",
	"RD_xrt3dHeaderYUseDefault",
	XtNxrt3dHeaderYUseDefault,
	"XtNxrt3dHeaderYUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dHeaderYUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumHeaderYUseDefault,
	FALSE,
	TRUE
},
{
	"xrt3dLegendAnchor",
	"RD_xrt3dLegendAnchor",
	XtNxrt3dLegendAnchor,
	"XtNxrt3dLegendAnchor",
	XRT3D_UX_ANCHOR,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendAnchor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendAnchor,
	FALSE,
	TRUE
},
{
	"xrt3dLegendBackgroundColor",
	"RD_xrt3dLegendBackgroundColor",
	XtNxrt3dLegendBackgroundColor,
	"XtNxrt3dLegendBackgroundColor",
	XRT3D_UX_COLOR,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendBackgroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendBackgroundColor,
	FALSE,
	TRUE
},
{
	"xrt3dLegendBorder",
	"RD_xrt3dLegendBorder",
	XtNxrt3dLegendBorder,
	"XtNxrt3dLegendBorder",
	XRT3D_UX_BORDER,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendBorder),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendBorder,
	FALSE,
	TRUE
},
{
	"xrt3dLegendBorderWidth",
	"RD_xrt3dLegendBorderWidth",
	XtNxrt3dLegendBorderWidth,
	"XtNxrt3dLegendBorderWidth",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendBorderWidth),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendBorderWidth,
	FALSE,
	TRUE
},
{
	"xrt3dLegendFont",
	"RD_xrt3dLegendFont",
	XtNxrt3dLegendFont,
	"XtNxrt3dLegendFont",
	XRT3D_UX_FONT_LIST,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendFont),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendFont,
	FALSE,
	TRUE
},
{
	"xrt3dLegendForegroundColor",
	"RD_xrt3dLegendForegroundColor",
	XtNxrt3dLegendForegroundColor,
	"XtNxrt3dLegendForegroundColor",
	XRT3D_UX_COLOR,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendForegroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendForegroundColor,
	FALSE,
	TRUE
},
{
	"xrt3dLegendHeight",
	"RD_xrt3dLegendHeight",
	XtNxrt3dLegendHeight,
	"XtNxrt3dLegendHeight",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendHeight),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendHeight,
	TRUE,
	TRUE
},
{
	"xrt3dLegendLabelFunc",
	"RD_xrt3dLegendLabelFunc",
	XtNxrt3dLegendLabelFunc,
	"XtNxrt3dLegendLabelFunc",
	XRT3D_UX_VOIDFUNCTION,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendLabelFunc),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendLabelFunc,
	FALSE,
	TRUE
},
{
	"xrt3dLegendOrientation",
	"RD_xrt3dLegendOrientation",
	XtNxrt3dLegendOrientation,
	"XtNxrt3dLegendOrientation",
	XRT3D_UX_ALIGN,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendOrientation),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendOrientation,
	FALSE,
	TRUE
},
{
	"xrt3dLegendShow",
	"RD_xrt3dLegendShow",
	XtNxrt3dLegendShow,
	"XtNxrt3dLegendShow",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendShow),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendShow,
	FALSE,
	TRUE
},
{
	"xrt3dLegendStrings",
	"RD_xrt3dLegendStrings",
	XtNxrt3dLegendStrings,
	"XtNxrt3dLegendStrings",
	XRT3D_UX_STRINGS,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendStrings),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendStrings,
	FALSE,
	TRUE
},
{
	"xrt3dLegendStyle",
	"RD_xrt3dLegendStyle",
	XtNxrt3dLegendStyle,
	"XtNxrt3dLegendStyle",
	XRT3D_UX_LEGENDSTYLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendStyle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendStyle,
	FALSE,
	TRUE
},
{
	"xrt3dLegendWidth",
	"RD_xrt3dLegendWidth",
	XtNxrt3dLegendWidth,
	"XtNxrt3dLegendWidth",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendWidth),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendWidth,
	TRUE,
	TRUE
},
{
	"xrt3dLegendX",
	"RD_xrt3dLegendX",
	XtNxrt3dLegendX,
	"XtNxrt3dLegendX",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendX),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendX,
	FALSE,
	TRUE
},
{
	"xrt3dLegendXUseDefault",
	"RD_xrt3dLegendXUseDefault",
	XtNxrt3dLegendXUseDefault,
	"XtNxrt3dLegendXUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendXUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumLegendXUseDefault,
	FALSE,
	TRUE
},
{
	"xrt3dLegendY",
	"RD_xrt3dLegendY",
	XtNxrt3dLegendY,
	"XtNxrt3dLegendY",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendY),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendY,
	FALSE,
	TRUE
},
{
	"xrt3dLegendYUseDefault",
	"RD_xrt3dLegendYUseDefault",
	XtNxrt3dLegendYUseDefault,
	"XtNxrt3dLegendYUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendYUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumLegendYUseDefault,
	FALSE,
	TRUE
},
{
	"xrt3dMapCallback",
	"RD_xrt3dMapCallback",
	XtNxrt3dMapCallback,
	"XtNxrt3dMapCallback",
	XRT3D_UX_CALLBACK,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dMapCallback),
	XRTDIV_BEHAVIOR,
	XRTPASS0,
	NULL,
	xrt3dResNumMapCallback,
	FALSE,
	TRUE
},
{
	"xrt3dMeshBottomColor",
	"RD_xrt3dMeshBottomColor",
	XtNxrt3dMeshBottomColor,
	"XtNxrt3dMeshBottomColor",
	XRT3D_UX_COLOR,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dMeshBottomColor),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumMeshBottomColor,
	FALSE,
	TRUE
},
{
	"xrt3dMeshTopColor",
	"RD_xrt3dMeshTopColor",
	XtNxrt3dMeshTopColor,
	"XtNxrt3dMeshTopColor",
	XRT3D_UX_COLOR,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dMeshTopColor),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumMeshTopColor,
	FALSE,
	TRUE
},
{
	"xrt3dModifyCallback",
	"RD_xrt3dModifyCallback",
	XtNxrt3dModifyCallback,
	"XtNxrt3dModifyCallback",
	XRT3D_UX_CALLBACK,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dModifyCallback),
	XRTDIV_BEHAVIOR,
	XRTPASS0,
	NULL,
	xrt3dResNumModifyCallback,
	FALSE,
	TRUE
},
{
	"xrt3dNumDistnLevels",
	"RD_xrt3dNumDistnLevels",
	XtNxrt3dNumDistnLevels,
	"XtNxrt3dNumDistnLevels",
	XRT3D_UX_INT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dNumDistnLevels),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumNumDistnLevels,
	FALSE,
	TRUE
},
{
	"xrt3dPerspectiveDepth",
	"RD_xrt3dPerspectiveDepth",
	XtNxrt3dPerspectiveDepth,
	"XtNxrt3dPerspectiveDepth",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dPerspectiveDepth),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumPerspectiveDepth,
	FALSE,
	TRUE
},
{
	"xrt3dPickCallback",
	"RD_xrt3dPickCallback",
	XtNxrt3dPickCallback,
	"XtNxrt3dPickCallback",
	XRT3D_UX_CALLBACK,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dPickCallback),
	XRTDIV_BEHAVIOR,
	XRTPASS0,
	NULL,
	xrt3dResNumPickCallback,
	FALSE,
	TRUE
},
{
	"xrt3dPreviewMethod",
	"RD_xrt3dPreviewMethod",
	XtNxrt3dPreviewMethod,
	"XtNxrt3dPreviewMethod",
	XRT3D_UX_PREVIEWMETHOD,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dPreviewMethod),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumPreviewMethod,
	FALSE,
	TRUE
},
{
	"xrt3dProjectZMax",
	"RD_xrt3dProjectZMax",
	XtNxrt3dProjectZMax,
	"XtNxrt3dProjectZMax",
	XRT3D_UX_PROJECT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dProjectZMax),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumProjectZMax,
	FALSE,
	TRUE
},
{
	"xrt3dProjectZMin",
	"RD_xrt3dProjectZMin",
	XtNxrt3dProjectZMin,
	"XtNxrt3dProjectZMin",
	XRT3D_UX_PROJECT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dProjectZMin),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumProjectZMin,
	FALSE,
	TRUE
},
{
	"xrt3dRepaint",
	"RD_xrt3dRepaint",
	XtNxrt3dRepaint,
	"XtNxrt3dRepaint",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dRepaint),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumRepaint,
	FALSE,
	TRUE
},
{
	"xrt3dResizeCallback",
	"RD_xrt3dResizeCallback",
	XtNxrt3dResizeCallback,
	"XtNxrt3dResizeCallback",
	XRT3D_UX_CALLBACK,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dResizeCallback),
	XRTDIV_BEHAVIOR,
	XRTPASS2,
	NULL,
	xrt3dResNumResizeCallback,
	FALSE,
	TRUE
},
{
	"xrt3dRotateCallback",
	"RD_xrt3dRotateCallback",
	XtNxrt3dRotateCallback,
	"XtNxrt3dRotateCallback",
	XRT3D_UX_CALLBACK,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dRotateCallback),
	XRTDIV_BEHAVIOR,
	XRTPASS0,
	NULL,
	xrt3dResNumRotateCallback,
	FALSE,
	TRUE
},
{
	"xrt3dSolidSurface",
	"RD_xrt3dSolidSurface",
	XtNxrt3dSolidSurface,
	"XtNxrt3dSolidSurface",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dSolidSurface),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumSolidSurface,
	FALSE,
	TRUE
},
{
	"xrt3dSurfaceBottomColor",
	"RD_xrt3dSurfaceBottomColor",
	XtNxrt3dSurfaceBottomColor,
	"XtNxrt3dSurfaceBottomColor",
	XRT3D_UX_COLOR,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dSurfaceBottomColor),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumSurfaceBottomColor,
	FALSE,
	TRUE
},
{
	"xrt3dSurfaceData",
	"RD_xrt3dSurfaceData",
	XtNxrt3dSurfaceData,
	"XtNxrt3dSurfaceData",
	XRT3D_UX_SURFACEDATA,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dSurfaceData),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumSurfaceData,
	FALSE,
	TRUE
},
{
	"xrt3dSurfaceTopColor",
	"RD_xrt3dSurfaceTopColor",
	XtNxrt3dSurfaceTopColor,
	"XtNxrt3dSurfaceTopColor",
	XRT3D_UX_COLOR,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dSurfaceTopColor),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumSurfaceTopColor,
	FALSE,
	TRUE
},
{
	"xrt3dTextList",
	"RD_xrt3dTextList",
	XtNxrt3dTextList,
	"XtNxrt3dTextList",
	XRT3D_UX_TEXTLIST,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dTextList),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumTextList,
	TRUE,
	TRUE
},
{
	"xrt3dTransformCallback",
	"RD_xrt3dTransformCallback",
	XtNxrt3dTransformCallback,
	"XtNxrt3dTransformCallback",
	XRT3D_UX_CALLBACK,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dTransformCallback),
	XRTDIV_BEHAVIOR,
	XRTPASS0,
	NULL,
	xrt3dResNumTransformCallback,
	FALSE,
	TRUE
},
{
	"xrt3dType",
	"RD_xrt3dType",
	XtNxrt3dType,
	"XtNxrt3dType",
	XRT3D_UX_TYPE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dType),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumType,
	FALSE,
	TRUE
},
{
	"xrt3dViewNormalized",
	"RD_xrt3dViewNormalized",
	XtNxrt3dViewNormalized,
	"XtNxrt3dViewNormalized",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dViewNormalized),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumViewNormalized,
	FALSE,
	TRUE
},
{
	"xrt3dViewScale",
	"RD_xrt3dViewScale",
	XtNxrt3dViewScale,
	"XtNxrt3dViewScale",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dViewScale),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumViewScale,
	FALSE,
	TRUE
},
{
	"xrt3dViewXTranslate",
	"RD_xrt3dViewXTranslate",
	XtNxrt3dViewXTranslate,
	"XtNxrt3dViewXTranslate",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dViewXTranslate),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumViewXTranslate,
	FALSE,
	TRUE
},
{
	"xrt3dViewYTranslate",
	"RD_xrt3dViewYTranslate",
	XtNxrt3dViewYTranslate,
	"XtNxrt3dViewYTranslate",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dViewYTranslate),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumViewYTranslate,
	FALSE,
	TRUE
},
{
	"xrt3dXAnnoMethod",
	"RD_xrt3dXAnnoMethod",
	XtNxrt3dXAnnoMethod,
	"XtNxrt3dXAnnoMethod",
	XRT3D_UX_ANNOMETHOD,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dXAnnoMethod),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumXAnnoMethod,
	FALSE,
	TRUE
},
{
	"xrt3dXAxisShow",
	"RD_xrt3dXAxisShow",
	XtNxrt3dXAxisShow,
	"XtNxrt3dXAxisShow",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dXAxisShow),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumXAxisShow,
	FALSE,
	TRUE
},
{
	"xrt3dXAxisTitle",
	"RD_xrt3dXAxisTitle",
	XtNxrt3dXAxisTitle,
	"XtNxrt3dXAxisTitle",
	XRT3D_UX_STRING,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dXAxisTitle),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumXAxisTitle,
	FALSE,
	TRUE
},
{
	"xrt3dXBarFormat",
	"RD_xrt3dXBarFormat",
	XtNxrt3dXBarFormat,
	"XtNxrt3dXBarFormat",
	XRT3D_UX_BARFORMAT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dXBarFormat),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumXBarFormat,
	FALSE,
	TRUE
},
{
	"xrt3dXBarSpacing",
	"RD_xrt3dXBarSpacing",
	XtNxrt3dXBarSpacing,
	"XtNxrt3dXBarSpacing",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dXBarSpacing),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumXBarSpacing,
	FALSE,
	TRUE
},
{
	"xrt3dXDataLabels",
	"RD_xrt3dXDataLabels",
	XtNxrt3dXDataLabels,
	"XtNxrt3dXDataLabels",
	XRT3D_UX_STRINGS,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dXDataLabels),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumXDataLabels,
	FALSE,
	TRUE
},
{
	"xrt3dXGridLines",
	"RD_xrt3dXGridLines",
	XtNxrt3dXGridLines,
	"XtNxrt3dXGridLines",
	XRT3D_UX_XGRIDLINES,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dXGridLines),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumXGridLines,
	FALSE,
	TRUE
},
{
	"xrt3dXMax",
	"RD_xrt3dXMax",
	XtNxrt3dXMax,
	"XtNxrt3dXMax",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dXMax),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumXMax,
	FALSE,
	TRUE
},
{
	"xrt3dXMaxUseDefault",
	"RD_xrt3dXMaxUseDefault",
	XtNxrt3dXMaxUseDefault,
	"XtNxrt3dXMaxUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dXMaxUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumXMaxUseDefault,
	FALSE,
	TRUE
},
{
	"xrt3dXMeshFilter",
	"RD_xrt3dXMeshFilter",
	XtNxrt3dXMeshFilter,
	"XtNxrt3dXMeshFilter",
	XRT3D_UX_INT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dXMeshFilter),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumXMeshFilter,
	FALSE,
	TRUE
},
{
	"xrt3dXMeshShow",
	"RD_xrt3dXMeshShow",
	XtNxrt3dXMeshShow,
	"XtNxrt3dXMeshShow",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dXMeshShow),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumXMeshShow,
	FALSE,
	TRUE
},
{
	"xrt3dXMin",
	"RD_xrt3dXMin",
	XtNxrt3dXMin,
	"XtNxrt3dXMin",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dXMin),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumXMin,
	FALSE,
	TRUE
},
{
	"xrt3dXMinUseDefault",
	"RD_xrt3dXMinUseDefault",
	XtNxrt3dXMinUseDefault,
	"XtNxrt3dXMinUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dXMinUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumXMinUseDefault,
	FALSE,
	TRUE
},
{
	"xrt3dXRotation",
	"RD_xrt3dXRotation",
	XtNxrt3dXRotation,
	"XtNxrt3dXRotation",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dXRotation),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumXRotation,
	FALSE,
	TRUE
},
{
	"xrt3dXScale",
	"RD_xrt3dXScale",
	XtNxrt3dXScale,
	"XtNxrt3dXScale",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dXScale),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumXScale,
	FALSE,
	TRUE
},
{
	"xrt3dXValueLabels",
	"RD_xrt3dXValueLabels",
	XtNxrt3dXValueLabels,
	"XtNxrt3dXValueLabels",
	XRT3D_UX_VALUELABELS,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dXValueLabels),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumXValueLabels,
	FALSE,
	TRUE
},
{
	"xrt3dXYColors",
	"RD_xrt3dXYColors",
	XtNxrt3dXYColors,
	"XtNxrt3dXYColors",
	XRT3D_UX_XYCOLORS,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dXYColors),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumXYColors,
	FALSE,
	TRUE
},
{
	"xrt3dYAnnoMethod",
	"RD_xrt3dYAnnoMethod",
	XtNxrt3dYAnnoMethod,
	"XtNxrt3dYAnnoMethod",
	XRT3D_UX_ANNOMETHOD,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dYAnnoMethod),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumYAnnoMethod,
	FALSE,
	TRUE
},
{
	"xrt3dYAxisShow",
	"RD_xrt3dYAxisShow",
	XtNxrt3dYAxisShow,
	"XtNxrt3dYAxisShow",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dYAxisShow),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumYAxisShow,
	FALSE,
	TRUE
},
{
	"xrt3dYAxisTitle",
	"RD_xrt3dYAxisTitle",
	XtNxrt3dYAxisTitle,
	"XtNxrt3dYAxisTitle",
	XRT3D_UX_STRING,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dYAxisTitle),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumYAxisTitle,
	FALSE,
	TRUE
},
{
	"xrt3dYBarFormat",
	"RD_xrt3dYBarFormat",
	XtNxrt3dYBarFormat,
	"XtNxrt3dYBarFormat",
	XRT3D_UX_BARFORMAT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dYBarFormat),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumYBarFormat,
	FALSE,
	TRUE
},
{
	"xrt3dYBarSpacing",
	"RD_xrt3dYBarSpacing",
	XtNxrt3dYBarSpacing,
	"XtNxrt3dYBarSpacing",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dYBarSpacing),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumYBarSpacing,
	FALSE,
	TRUE
},
{
	"xrt3dYDataLabels",
	"RD_xrt3dYDataLabels",
	XtNxrt3dYDataLabels,
	"XtNxrt3dYDataLabels",
	XRT3D_UX_STRINGS,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dYDataLabels),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumYDataLabels,
	FALSE,
	TRUE
},
{
	"xrt3dYGridLines",
	"RD_xrt3dYGridLines",
	XtNxrt3dYGridLines,
	"XtNxrt3dYGridLines",
	XRT3D_UX_YGRIDLINES,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dYGridLines),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumYGridLines,
	FALSE,
	TRUE
},
{
	"xrt3dYMax",
	"RD_xrt3dYMax",
	XtNxrt3dYMax,
	"XtNxrt3dYMax",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dYMax),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumYMax,
	FALSE,
	TRUE
},
{
	"xrt3dYMaxUseDefault",
	"RD_xrt3dYMaxUseDefault",
	XtNxrt3dYMaxUseDefault,
	"XtNxrt3dYMaxUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dYMaxUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumYMaxUseDefault,
	FALSE,
	TRUE
},
{
	"xrt3dYMeshFilter",
	"RD_xrt3dYMeshFilter",
	XtNxrt3dYMeshFilter,
	"XtNxrt3dYMeshFilter",
	XRT3D_UX_INT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dYMeshFilter),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumYMeshFilter,
	FALSE,
	TRUE
},
{
	"xrt3dYMeshShow",
	"RD_xrt3dYMeshShow",
	XtNxrt3dYMeshShow,
	"XtNxrt3dYMeshShow",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dYMeshShow),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumYMeshShow,
	FALSE,
	TRUE
},
{
	"xrt3dYMin",
	"RD_xrt3dYMin",
	XtNxrt3dYMin,
	"XtNxrt3dYMin",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dYMin),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumYMin,
	FALSE,
	TRUE
},
{
	"xrt3dYMinUseDefault",
	"RD_xrt3dYMinUseDefault",
	XtNxrt3dYMinUseDefault,
	"XtNxrt3dYMinUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dYMinUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumYMinUseDefault,
	FALSE,
	TRUE
},
{
	"xrt3dYRotation",
	"RD_xrt3dYRotation",
	XtNxrt3dYRotation,
	"XtNxrt3dYRotation",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dYRotation),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumYRotation,
	FALSE,
	TRUE
},
{
	"xrt3dYScale",
	"RD_xrt3dYScale",
	XtNxrt3dYScale,
	"XtNxrt3dYScale",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dYScale),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumYScale,
	FALSE,
	TRUE
},
{
	"xrt3dYValueLabels",
	"RD_xrt3dYValueLabels",
	XtNxrt3dYValueLabels,
	"XtNxrt3dYValueLabels",
	XRT3D_UX_VALUELABELS,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dYValueLabels),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumYValueLabels,
	FALSE,
	TRUE
},
{
	"xrt3dZAnnoMethod",
	"RD_xrt3dZAnnoMethod",
	XtNxrt3dZAnnoMethod,
	"XtNxrt3dZAnnoMethod",
	XRT3D_UX_ANNOMETHOD,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dZAnnoMethod),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumZAnnoMethod,
	FALSE,
	TRUE
},
{
	"xrt3dZAxisShow",
	"RD_xrt3dZAxisShow",
	XtNxrt3dZAxisShow,
	"XtNxrt3dZAxisShow",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dZAxisShow),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumZAxisShow,
	FALSE,
	TRUE
},
{
	"xrt3dZAxisTitle",
	"RD_xrt3dZAxisTitle",
	XtNxrt3dZAxisTitle,
	"XtNxrt3dZAxisTitle",
	XRT3D_UX_STRING,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dZAxisTitle),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumZAxisTitle,
	FALSE,
	TRUE
},
{
	"xrt3dZGridLines",
	"RD_xrt3dZGridLines",
	XtNxrt3dZGridLines,
	"XtNxrt3dZGridLines",
	XRT3D_UX_ZGRIDLINES,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dZGridLines),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumZGridLines,
	FALSE,
	TRUE
},
{
	"xrt3dZMax",
	"RD_xrt3dZMax",
	XtNxrt3dZMax,
	"XtNxrt3dZMax",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dZMax),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumZMax,
	FALSE,
	TRUE
},
{
	"xrt3dZMaxUseDefault",
	"RD_xrt3dZMaxUseDefault",
	XtNxrt3dZMaxUseDefault,
	"XtNxrt3dZMaxUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dZMaxUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumZMaxUseDefault,
	FALSE,
	TRUE
},
{
	"xrt3dZMin",
	"RD_xrt3dZMin",
	XtNxrt3dZMin,
	"XtNxrt3dZMin",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dZMin),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumZMin,
	FALSE,
	TRUE
},
{
	"xrt3dZMinUseDefault",
	"RD_xrt3dZMinUseDefault",
	XtNxrt3dZMinUseDefault,
	"XtNxrt3dZMinUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dZMinUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumZMinUseDefault,
	FALSE,
	TRUE
},
{
	"xrt3dZOrigin",
	"RD_xrt3dZOrigin",
	XtNxrt3dZOrigin,
	"XtNxrt3dZOrigin",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dZOrigin),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumZOrigin,
	FALSE,
	TRUE
},
{
	"xrt3dZRotation",
	"RD_xrt3dZRotation",
	XtNxrt3dZRotation,
	"XtNxrt3dZRotation",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dZRotation),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumZRotation,
	FALSE,
	TRUE
},
{
	"xrt3dZScale",
	"RD_xrt3dZScale",
	XtNxrt3dZScale,
	"XtNxrt3dZScale",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dZScale),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumZScale,
	FALSE,
	TRUE
},
{
	"xrt3dZValueLabels",
	"RD_xrt3dZValueLabels",
	XtNxrt3dZValueLabels,
	"XtNxrt3dZValueLabels",
	XRT3D_UX_VALUELABELS,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dZValueLabels),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumZValueLabels,
	FALSE,
	TRUE
},
{
	"xrt3dZoneData",
	"RD_xrt3dZoneData",
	XtNxrt3dZoneData,
	"XtNxrt3dZoneData",
	XRT3D_UX_ZONEDATA,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dZoneData),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrt3dResNumZoneData,
	FALSE,
	TRUE
},
{
	"xrt3dZoneMethod",
	"RD_xrt3dZoneMethod",
	XtNxrt3dZoneMethod,
	"XtNxrt3dZoneMethod",
	XRT3D_UX_ZONEMETHOD,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dZoneMethod),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumZoneMethod,
	FALSE,
	TRUE
},
{
	"xrt3dColorFunc",
	"RD_xrt3dColorFunc",
	XtNxrt3dColorFunc,
	"XtNxrt3dColorFunc",
	XRT3D_UX_VOIDFUNCTION,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dColorFunc),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumColorFunc,
	FALSE,
	TRUE
},
{
	"xrt3dDataStyles",
	"RD_xrt3dDataStyles",
	XtNxrt3dDataStyles,
	"XtNxrt3dDataStyles",
	XRT3D_UX_DATASTYLES,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dDataStyles),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumDataStyles,
	FALSE,
	TRUE
},
{
	"xrt3dDataStylesUseDefault",
	"RD_xrt3dDataStylesUseDefault",
	XtNxrt3dDataStylesUseDefault,
	"XtNxrt3dDataStylesUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dDataStylesUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumDataStylesUseDefault,
	FALSE,
	TRUE
},
{
	"xrt3dDrawDropLines",
	"RD_xrt3dDrawDropLines",
	XtNxrt3dDrawDropLines,
	"XtNxrt3dDrawDropLines",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dDrawDropLines),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumDrawDropLines,
	FALSE,
	TRUE
},
{
	"xrt3dFooterImage",
	"RD_xrt3dFooterImage",
	XtNxrt3dFooterImage,
	"XtNxrt3dFooterImage",
	XRT3D_UX_IMAGE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dFooterImage),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumFooterImage,
	FALSE,
	TRUE
},
{
	"xrt3dFooterImageLayout",
	"RD_xrt3dFooterImageLayout",
	XtNxrt3dFooterImageLayout,
	"XtNxrt3dFooterImageLayout",
	XRT3D_UX_IMAGELAYOUT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dFooterImageLayout),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumFooterImageLayout,
	FALSE,
	TRUE
},
{
	"xrt3dFooterImageMinimumSize",
	"RD_xrt3dFooterImageMinimumSize",
	XtNxrt3dFooterImageMinimumSize,
	"XtNxrt3dFooterImageMinimumSize",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dFooterImageMinimumSize),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumFooterImageMinimumSize,
	FALSE,
	TRUE
},
{
	"xrt3dGraphImage",
	"RD_xrt3dGraphImage",
	XtNxrt3dGraphImage,
	"XtNxrt3dGraphImage",
	XRT3D_UX_IMAGE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dGraphImage),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumGraphImage,
	FALSE,
	TRUE
},
{
	"xrt3dGraphImageLayout",
	"RD_xrt3dGraphImageLayout",
	XtNxrt3dGraphImageLayout,
	"XtNxrt3dGraphImageLayout",
	XRT3D_UX_IMAGELAYOUT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dGraphImageLayout),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumGraphImageLayout,
	FALSE,
	TRUE
},
{
	"xrt3dHeaderImage",
	"RD_xrt3dHeaderImage",
	XtNxrt3dHeaderImage,
	"XtNxrt3dHeaderImage",
	XRT3D_UX_IMAGE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dHeaderImage),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumHeaderImage,
	FALSE,
	TRUE
},
{
	"xrt3dHeaderImageLayout",
	"RD_xrt3dHeaderImageLayout",
	XtNxrt3dHeaderImageLayout,
	"XtNxrt3dHeaderImageLayout",
	XRT3D_UX_IMAGELAYOUT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dHeaderImageLayout),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumHeaderImageLayout,
	FALSE,
	TRUE
},
{
	"xrt3dHeaderImageMinimumSize",
	"RD_xrt3dHeaderImageMinimumSize",
	XtNxrt3dHeaderImageMinimumSize,
	"XtNxrt3dHeaderImageMinimumSize",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dHeaderImageMinimumSize),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumHeaderImageMinimumSize,
	FALSE,
	TRUE
},
{
	"xrt3dImage",
	"RD_xrt3dImage",
	XtNxrt3dImage,
	"XtNxrt3dImage",
	XRT3D_UX_IMAGE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dImage),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumImage,
	FALSE,
	TRUE
},
{
	"xrt3dImageLayout",
	"RD_xrt3dImageLayout",
	XtNxrt3dImageLayout,
	"XtNxrt3dImageLayout",
	XRT3D_UX_IMAGELAYOUT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dImageLayout),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumImageLayout,
	FALSE,
	TRUE
},
{
	"xrt3dLegendDistnRange",
	"RD_xrt3dLegendDistnRange",
	XtNxrt3dLegendDistnRange,
	"XtNxrt3dLegendDistnRange",
	XRT3D_UX_DISTNRANGE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendDistnRange),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendDistnRange,
	FALSE,
	TRUE
},
{
	"xrt3dLegendImage",
	"RD_xrt3dLegendImage",
	XtNxrt3dLegendImage,
	"XtNxrt3dLegendImage",
	XRT3D_UX_IMAGE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendImage),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendImage,
	FALSE,
	TRUE
},
{
	"xrt3dLegendImageLayout",
	"RD_xrt3dLegendImageLayout",
	XtNxrt3dLegendImageLayout,
	"XtNxrt3dLegendImageLayout",
	XRT3D_UX_IMAGELAYOUT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendImageLayout),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendImageLayout,
	FALSE,
	TRUE
},
{
	"xrt3dLegendLabelFilter",
	"RD_xrt3dLegendLabelFilter",
	XtNxrt3dLegendLabelFilter,
	"XtNxrt3dLegendLabelFilter",
	XRT3D_UX_INT,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendLabelFilter),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendLabelFilter,
	FALSE,
	TRUE
},
{
	"xrt3dLegendTitle",
	"RD_xrt3dLegendTitle",
	XtNxrt3dLegendTitle,
	"XtNxrt3dLegendTitle",
	XRT3D_UX_STRING,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dLegendTitle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumLegendTitle,
	FALSE,
	TRUE
},
{
	"xrt3dXGridLineStyle",
	"RD_xrt3dXGridLineStyle",
	XtNxrt3dXGridLineStyle,
	"XtNxrt3dXGridLineStyle",
	XRT3D_UX_LINESTYLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dXGridLineStyle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumXGridLineStyle,
	FALSE,
	TRUE
},
{
	"xrt3dXGridLineStyleUseDefault",
	"RD_xrt3dXGridLineStyleUseDefault",
	XtNxrt3dXGridLineStyleUseDefault,
	"XtNxrt3dXGridLineStyleUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dXGridLineStyleUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumXGridLineStyleUseDefault,
	FALSE,
	TRUE
},
{
	"xrt3dYGridLineStyle",
	"RD_xrt3dYGridLineStyle",
	XtNxrt3dYGridLineStyle,
	"XtNxrt3dYGridLineStyle",
	XRT3D_UX_LINESTYLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dYGridLineStyle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumYGridLineStyle,
	FALSE,
	TRUE
},
{
	"xrt3dYGridLineStyleUseDefault",
	"RD_xrt3dYGridLineStyleUseDefault",
	XtNxrt3dYGridLineStyleUseDefault,
	"XtNxrt3dYGridLineStyleUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dYGridLineStyleUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumYGridLineStyleUseDefault,
	FALSE,
	TRUE
},
{
	"xrt3dZGridLineStyle",
	"RD_xrt3dZGridLineStyle",
	XtNxrt3dZGridLineStyle,
	"XtNxrt3dZGridLineStyle",
	XRT3D_UX_LINESTYLE,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dZGridLineStyle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumZGridLineStyle,
	FALSE,
	TRUE
},
{
	"xrt3dZGridLineStyleUseDefault",
	"RD_xrt3dZGridLineStyleUseDefault",
	XtNxrt3dZGridLineStyleUseDefault,
	"XtNxrt3dZGridLineStyleUseDefault",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dClass, Xrt3d.RD_xrt3dZGridLineStyleUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dResNumZGridLineStyleUseDefault,
	FALSE,
	TRUE
}
};

int num3d_res = (sizeof(xrt3d_res_table) / sizeof(xrt3d_res_table[0]));

Xrt3dResourceDesc xrt3dtext_res_table[] = {
{
	"xrt3dTextAdjust",
	"RD_xrt3dTextAdjust",
	XtNxrt3dTextAdjust,
	"XtNxrt3dTextAdjust",
	XRT3D_UX_ADJUST,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextAdjust),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumAdjust,
	FALSE,
	TRUE
},
{
	"xrt3dTextAttachIndexX",
	"RD_xrt3dTextAttachIndexX",
	XtNxrt3dTextAttachIndexX,
	"XtNxrt3dTextAttachIndexX",
	XRT3D_UX_INT,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextAttachIndexX),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumAttachIndexX,
	FALSE,
	TRUE
},
{
	"xrt3dTextAttachIndexY",
	"RD_xrt3dTextAttachIndexY",
	XtNxrt3dTextAttachIndexY,
	"XtNxrt3dTextAttachIndexY",
	XRT3D_UX_INT,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextAttachIndexY),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumAttachIndexY,
	FALSE,
	TRUE
},
{
	"xrt3dTextAttachMethod",
	"RD_xrt3dTextAttachMethod",
	XtNxrt3dTextAttachMethod,
	"XtNxrt3dTextAttachMethod",
	XRT3D_UX_ATTACHMETHOD,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextAttachMethod),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumAttachMethod,
	FALSE,
	TRUE
},
{
	"xrt3dTextAttachPixelX",
	"RD_xrt3dTextAttachPixelX",
	XtNxrt3dTextAttachPixelX,
	"XtNxrt3dTextAttachPixelX",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextAttachPixelX),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumAttachPixelX,
	FALSE,
	TRUE
},
{
	"xrt3dTextAttachPixelY",
	"RD_xrt3dTextAttachPixelY",
	XtNxrt3dTextAttachPixelY,
	"XtNxrt3dTextAttachPixelY",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextAttachPixelY),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumAttachPixelY,
	FALSE,
	TRUE
},
{
	"xrt3dTextAttachPointX",
	"RD_xrt3dTextAttachPointX",
	XtNxrt3dTextAttachPointX,
	"XtNxrt3dTextAttachPointX",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextAttachPointX),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumAttachPointX,
	FALSE,
	TRUE
},
{
	"xrt3dTextAttachPointY",
	"RD_xrt3dTextAttachPointY",
	XtNxrt3dTextAttachPointY,
	"XtNxrt3dTextAttachPointY",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextAttachPointY),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumAttachPointY,
	FALSE,
	TRUE
},
{
	"xrt3dTextAttachPointZ",
	"RD_xrt3dTextAttachPointZ",
	XtNxrt3dTextAttachPointZ,
	"XtNxrt3dTextAttachPointZ",
	XRT3D_UX_DOUBLE,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextAttachPointZ),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumAttachPointZ,
	FALSE,
	TRUE
},
{
	"xrt3dTextBackgroundColor",
	"RD_xrt3dTextBackgroundColor",
	XtNxrt3dTextBackgroundColor,
	"XtNxrt3dTextBackgroundColor",
	XRT3D_UX_COLOR,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextBackgroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumBackgroundColor,
	FALSE,
	TRUE
},
{
	"xrt3dTextBorder",
	"RD_xrt3dTextBorder",
	XtNxrt3dTextBorder,
	"XtNxrt3dTextBorder",
	XRT3D_UX_BORDER,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextBorder),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumBorder,
	FALSE,
	TRUE
},
{
	"xrt3dTextBorderWidth",
	"RD_xrt3dTextBorderWidth",
	XtNxrt3dTextBorderWidth,
	"XtNxrt3dTextBorderWidth",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextBorderWidth),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumBorderWidth,
	FALSE,
	TRUE
},
{
	"xrt3dTextFont",
	"RD_xrt3dTextFont",
	XtNxrt3dTextFont,
	"XtNxrt3dTextFont",
	XRT3D_UX_FONT_LIST,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextFont),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumFont,
	FALSE,
	TRUE
},
{
	"xrt3dTextForegroundColor",
	"RD_xrt3dTextForegroundColor",
	XtNxrt3dTextForegroundColor,
	"XtNxrt3dTextForegroundColor",
	XRT3D_UX_COLOR,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextForegroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumForegroundColor,
	FALSE,
	TRUE
},
{
	"xrt3dTextLineShow",
	"RD_xrt3dTextLineShow",
	XtNxrt3dTextLineShow,
	"XtNxrt3dTextLineShow",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextLineShow),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumLineShow,
	FALSE,
	TRUE
},
{
	"xrt3dTextOffsetX",
	"RD_xrt3dTextOffsetX",
	XtNxrt3dTextOffsetX,
	"XtNxrt3dTextOffsetX",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextOffsetX),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumOffsetX,
	FALSE,
	TRUE
},
{
	"xrt3dTextOffsetY",
	"RD_xrt3dTextOffsetY",
	XtNxrt3dTextOffsetY,
	"XtNxrt3dTextOffsetY",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextOffsetY),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumOffsetY,
	FALSE,
	TRUE
},
{
	"xrt3dTextPrintFont",
	"RD_xrt3dTextPrintFont",
	XtNxrt3dTextPrintFont,
	"XtNxrt3dTextPrintFont",
	XRT3D_UX_STRING,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextPrintFont),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumPrintFont,
	FALSE,
	TRUE
},
{
	"xrt3dTextPlane",
	"RD_xrt3dTextPlane",
	XtNxrt3dTextPlane,
	"XtNxrt3dTextPlane",
	XRT3D_UX_PLANE,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextPlane),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumPlane,
	FALSE,
	TRUE
},
{
	"xrt3dTextShow",
	"RD_xrt3dTextShow",
	XtNxrt3dTextShow,
	"XtNxrt3dTextShow",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextShow),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumShow,
	FALSE,
	TRUE
},
{
	"xrt3dTextStrings",
	"RD_xrt3dTextStrings",
	XtNxrt3dTextStrings,
	"XtNxrt3dTextStrings",
	XRT3D_UX_STRINGS,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextStrings),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumStrings,
	FALSE,
	TRUE
},
{
	"xrt3dTextStrokeFont",
	"RD_xrt3dTextStrokeFont",
	XtNxrt3dTextStrokeFont,
	"XtNxrt3dTextStrokeFont",
	XRT3D_UX_STROKEFONT,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextStrokeFont),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumStrokeFont,
	FALSE,
	TRUE
},
{
	"xrt3dTextStrokeSize",
	"RD_xrt3dTextStrokeSize",
	XtNxrt3dTextStrokeSize,
	"XtNxrt3dTextStrokeSize",
	XRT3D_UX_SHORT,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextStrokeSize),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumStrokeSize,
	FALSE,
	TRUE
},
{
	"xrt3dTextAttachIndexPoint",
	"RD_xrt3dTextAttachIndexPoint",
	XtNxrt3dTextAttachIndexPoint,
	"XtNxrt3dTextAttachIndexPoint",
	XRT3D_UX_INT,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextAttachIndexPoint),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumAttachIndexPoint,
	FALSE,
	TRUE
},
{
	"xrt3dTextAttachIndexSeries",
	"RD_xrt3dTextAttachIndexSeries",
	XtNxrt3dTextAttachIndexSeries,
	"XtNxrt3dTextAttachIndexSeries",
	XRT3D_UX_INT,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextAttachIndexSeries),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumAttachIndexSeries,
	FALSE,
	TRUE
},
{
	"xrt3dTextImage",
	"RD_xrt3dTextImage",
	XtNxrt3dTextImage,
	"XtNxrt3dTextImage",
	XRT3D_UX_IMAGE,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextImage),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumImage,
	FALSE,
	TRUE
},
{
	"xrt3dTextImageLayout",
	"RD_xrt3dTextImageLayout",
	XtNxrt3dTextImageLayout,
	"XtNxrt3dTextImageLayout",
	XRT3D_UX_IMAGELAYOUT,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextImageLayout),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumImageLayout,
	FALSE,
	TRUE
},
{
	"xrt3dTextImageMinimumSize",
	"RD_xrt3dTextImageMinimumSize",
	XtNxrt3dTextImageMinimumSize,
	"XtNxrt3dTextImageMinimumSize",
	XRT3D_UX_BOOL,
	{0, 0, 0},
	Offset(UxXrt3dTextClass, Xrt3dText.RD_xrt3dTextImageMinimumSize),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrt3dTextResNumImageMinimumSize,
	FALSE,
	TRUE
}
};

int num3dtext_res =
(sizeof(xrt3dtext_res_table) / sizeof(xrt3dtext_res_table[0]));

XrtResourceType **xrt3d_res_types = NULL;
int				num3d_res_types;

void
Xrt3d_init_resource_types()
{
	XrtResourceType	*type;
	int				n;
	static Boolean	AlreadyDone = FALSE;
	
	if (AlreadyDone) {
		return;
	}

	n = 0;
	xrt3d_res_types = (XrtResourceType **)
		calloc(n+2, sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_BOOL;
	type->utype = UxUT_string;
	type->xtype = UxXT_Boolean;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfBoolean;
	type->validate = UxValidateBoolean;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_CALLBACK;
	type->utype = (short) 0;
	type->xtype = 0;
	type->convert_flag = 0;
	type->converter = NULL;
	type->values_of = NULL;
	type->validate = NULL;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_COLOR;
	type->utype = UxUT_string;
	type->xtype = UxXT_String;
	type->convert_flag = 0;
	type->converter = NULL;
	type->values_of = UxValuesOfString;
	type->validate = UxValidateString;
	type->edit_func = UxGUIPopupColorView;
	type->get_func = NULL;
	type->put_func = NULL;
 	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_DOUBLE;
	type->utype = UxUT_float;
	type->xtype = UxXT_Xrt3dDouble;
	type->convert_flag = 0;
	type->converter = "UxConvertXrt3dDouble";
	type->values_of = UxValuesOfXrt3dDouble;
	type->validate = UxValidateInt;
	type->edit_func = NULL;
	type->get_func = (int (*)())Xrt3dGetDouble;
	type->put_func = Xrt3dPutDouble;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_INT;
	type->utype = UxUT_int;
	type->xtype = UxXT_int;
	type->convert_flag = 0;
	type->converter = NULL;
	type->values_of = UxValuesOfInt;
	type->validate = UxValidateInt;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_SHORT;
	type->utype = UxUT_short;
	type->xtype = UxXT_short;
	type->convert_flag = 0;
	type->converter = NULL;
	type->values_of = UxValuesOfInt;
	type->validate = UxValidateInt;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_STRING;
	type->utype = UxUT_string;
	type->xtype = UxXT_String;
	type->convert_flag = 0;
	type->converter = NULL;
	type->values_of = UxValuesOfString;
	type->validate = UxValidateString;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_VOIDFUNCTION;
	type->utype = UxUT_voidFunction;
	type->xtype = UxXT_String;
	type->convert_flag = 0;
	type->converter = NULL;
	type->values_of = UxValuesOfVoidFunction;
	type->validate = UxValidateVoidFunction;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	/*pds*/	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_FONT_LIST;
	type->utype = UxUT_string;
	type->xtype = UxXT_XmFontList;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXmFontList;
	type->validate = UxValidateXmFontList;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_ADJUST;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dAdjust;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dAdjust;
	type->validate = UxValidateXrt3dAdjust;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_ALIGN;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dAlign;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dAlign;
	type->validate = UxValidateXrt3dAlign;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_ANCHOR;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dAnchor;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dAnchor;
	type->validate = UxValidateXrt3dAnchor;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_ANNOMETHOD;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dAnnoMethod;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dAnnoMethod;
	type->validate = UxValidateXrt3dAnnoMethod;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_ATTACHMETHOD;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dAttachMethod;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dAttachMethod;
	type->validate = UxValidateXrt3dAttachMethod;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;

	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_BARFORMAT;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dBarFormat;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dBarFormat;
	type->validate = UxValidateXrt3dBarFormat;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_BORDER;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dBorder;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dBorder;
	type->validate = UxValidateXrt3dBorder;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_CONTOURSTYLES;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dContourStyles;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dContourStyles;
	type->validate = UxValidateString;
	type->edit_func = UxPopupXrt3dContourStyles;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_DISTNMETHOD;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dDistnMethod;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dDistnMethod;
	type->validate = UxValidateXrt3dDistnMethod;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_DISTNTABLE;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dDistnTable;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dDistnTable;
	type->validate = UxValidateXrt3dDistnTable;
	type->edit_func = UxPopupXrt3dDistnTable;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_LEGENDSTYLE;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dLegendStyle;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dLegendStyle;
	type->validate = UxValidateXrt3dLegendStyle;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_PREVIEWMETHOD;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dPreviewMethod;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dPreviewMethod;
	type->validate = UxValidateXrt3dPreviewMethod;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_PLANE;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dPlane;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dPlane;
	type->validate = UxValidateXrt3dPlane;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_PROJECT;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dProject;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dProject;
	type->validate = UxValidateXrt3dProject;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_STRINGS;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dStrings;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dStrings;
	type->validate = UxValidateString;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_STROKEFONT;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dStrokeFont;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dStrokeFont;
	type->validate = UxValidateXrt3dStrokeFont;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_SURFACEDATA;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dSurfaceData;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dData;
	type->validate = UxValidateXrt3dData;
	type->edit_func = UxPopupXrt3dSurfaceData;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_TEXTLIST;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dTextList;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dTextList;
	type->validate = UxValidateString;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_TYPE;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dType;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dType;
	type->validate = UxValidateXrt3dType;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_VALUELABELS;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dValueLabels;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dValueLabels;
	type->validate = UxValidateString;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_XYCOLORS;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dXYColors;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dXYColors;
	type->validate = UxValidateString;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_XGRIDLINES;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dXGridLines;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dXGridLines;
	type->validate = UxValidateXrt3dXGridLines;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_YGRIDLINES;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dYGridLines;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dYGridLines;
	type->validate = UxValidateXrt3dYGridLines;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_ZGRIDLINES;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dZGridLines;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dZGridLines;
	type->validate = UxValidateXrt3dZGridLines;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_ZONEDATA;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dZoneData;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dData;
	type->validate = UxValidateXrt3dData;
	type->edit_func = UxPopupXrt3dZoneData;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;
	
	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_ZONEMETHOD;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dZoneMethod;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dZoneMethod;
	type->validate = UxValidateXrt3dZoneMethod;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;

	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_DATASTYLES;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dDataStyles;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dDataStyles;
	type->validate = UxValidateString;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;

	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_DISTNRANGE;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dDistnRange;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dDistnRange;
	type->validate = UxValidateXrt3dDistnRange;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;

	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_IMAGE;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dImage;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dImage;
	type->validate = UxValidateString;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;

	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_IMAGELAYOUT;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dImageLayout;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dImageLayout;
	type->validate = UxValidateXrt3dImageLayout;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;

	xrt3d_res_types = (XrtResourceType **)
		realloc(xrt3d_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_3d = XRT3D_UX_LINESTYLE;
	type->utype = UxUT_string;
	type->xtype = UxXT_Xrt3dLineStyle;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrt3dLineStyle;
	type->validate = UxValidateString;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrt3d_res_types[n++] = type;

 	xrt3d_res_types[n] = NULL;
	num3d_res_types = n;
	AlreadyDone = TRUE;

}

static void
Xrt3d_initialize_resources(table, nres, nres_string)
Xrt3dResourceDesc	*table;
int					nres;
char				*nres_string;
{
	int		itype, n;
	char	buffer[128];
	
	for (n = 0; n < nres; n++) {
		itype = (int) table[n].res_type;
		table[n].type = xrt3d_res_types[itype];
		if (table[n].resnum != n) {
			sprintf(buffer,
					"3d resource number (%d) & table number (%d) unequal!",
					table[n].resnum, n);
			printf("%s\n", buffer);
		}
	}

}

void
Xrt3d_init_resource_table()
{
	static Boolean	AlreadyDone = FALSE;

	if (AlreadyDone) {
		return;
	}
	
	Xrt3d_init_resource_types();

	Xrt3d_initialize_resources(xrt3d_res_table, num3d_res, "num3d_res");
	Xrt3d_initialize_resources(xrt3dtext_res_table, num3dtext_res,
							   "num3dtext_res");
	AlreadyDone = TRUE;
	
}

#ifdef DESIGN_TIME

/* Double functions */

static float
Xrt3dGetDouble(sw, res)
swidget         sw;
Resource_t      *res;
{
	Widget		w;
	double		value  = 0.0;
	char		*ptr;
	XtArgVal	argval;

	ptr = UxGetXtName(res);
	if (UxIsSwidget(sw))
		if ((w = UxGetWidget(sw)) != NULL)
			XtVaGetValues (w, ptr, &value, NULL);
		else
			if(UxFindValue(sw, res, &argval))
				value = Xrt3dArgValToDouble(argval);

#ifdef osf1
#include <limits.h>
	if (value > FLT_MAX) {
		value = FLT_MAX;
	}
	if (value < -FLT_MAX) {
		value = -FLT_MAX;
	}
#endif /* osf1 */
	return (float)value;
}


static int
Xrt3dPutDouble(sw, res, intvalue)
swidget		sw;
Resource_t	*res;
int			intvalue;
{

	Widget		w;
	char		*ptr;
	int		status = ERROR;
	XtArgVal	argval;
	FloatInt_t	localcast;
	float		value;

	localcast.i = intvalue;
	value = localcast.f;

	ptr = UxGetXtName(res);

	if (UxIsSwidget(sw)) {
		argval = Xrt3dDoubleToArgVal((double)value);
		UxSaveValue (sw, res, argval, FALSE);

		/*
		 *  If the delay flag is NOT set, update widget now
		 *  so that the change happens immediately in the
		 *  property editor.
		 */
		if(!UxGetDelay(sw) && (w = (Widget) UxGetWidget(sw)) != NULL) {
			XtVaSetValues(w, ptr, argval, NULL);
		}

		status = NO_ERROR;
	}
	else {
		status = ERROR;
	}
	
	return(status);
}

#else

static float Xrt3dGetDouble() {}
static int   Xrt3dPutDouble() {}

#endif /* DESIGN_TIME */
