/*------------------------------------------------------------------------------
 * $AstecId: UxSwidget.cc,v 1.5 1999/11/24 07:41:16 nakayama Exp $
 * $Source: /proj/uimx/XRTPDS/integrate-xrt/custom/RCS/UxSwidget.cc,v $
 * $Date: 1999/11/09 04:14:23 $             $Revision: 1.4 $
 *------------------------------------------------------------------------------
 *             Copyright (c) 1996, Visual Edge Software Ltd.
 *
 * ALL  RIGHTS  RESERVED.  Permission  to  use,  copy,  modify,  and
 * distribute  this  software  and its documentation for any purpose
 * and  without  fee  is  hereby  granted,  provided  that the above
 * copyright  notice  appear  in  all  copies  and  that  both  that
 * copyright  notice and this permission notice appear in supporting
 * documentation,  and that  the name of Visual Edge Software not be
 * used  in advertising  or publicity  pertaining to distribution of
 * the software without specific, written prior permission. The year
 * included in the notice is the year of the creation of the work.
 *------------------------------------------------------------------------------
 * Design time implementation of the several of the base classes of the
 * C++ convenience classes. 
 *
 * This is the root of the UxC++ convenience library object structure. They
 * are hand coded since their counterpart include files are. Any new
 * convenience functions added to one of the following classes in the include
 * file need to be defined here.
 * 
 * The classes are:
 *
 *	UxBase
 *	UxSwidget
 *	UxInterface (UXINLINE functions only)
 *----------------------------------------------------------------------------*/

#include <UxSwidget.h>
#include <stdgetput.h>
#include <UxInterf.h>
#include <UxLib.h>


#include <UxForm.h>
#include <UxFrame.h>
#include <UxPaneW.h>
#ifdef sgi
#include <UxGrid.h>
#include <UxSpringB.h>
#endif /* sgi */
#ifdef	XRT
#ifdef	HASXRTGEAR
#include <UxXrtAligner.h>
#include <UxXrtTabM.h>
#include <UxXrtToolbar.h>
#endif	/* HASXRTGEAR */
#ifdef HASXRTTABLE
#include <UxXrtTable.h>
#endif /* HASXRTTABLE */
#endif	/* XRT */

extern "C"  WidgetClass UxGetDefaultShellClass UXPROTO(( swidget ));

// Constructors
UxSwidget::UxSwidget() {}

// Destructor
UxSwidget::~UxSwidget() {}


UxBase::UxBase()
{
	UxThis = NULL;
}

UxBase::~UxBase()
{
}

UxBase::operator swidget()
{
	return UxThis;
}

UxBase::operator swidget() const
{
	return UxThis;
}

UxBase::operator void*()
{
	return (void *) UxThis;
}

UxBase::operator const void*() const
{
	return (const void *) UxThis;
}

Widget UxBase::GetWidget() 
{
	return UxGetWidget(UxThis);
}

int UxBase::IsValidSwidget() const
{
	return UxIsValidSwidget(UxThis);
}

swidget UxBase::GetParent() 
{
	return UxGetParent(UxThis);
}

char* UxBase::GetName(void) const
{
	return UxGetName(UxThis);
}

char* UxBase::GetCreateManaged(void) const
{
	return UxGetCreateManaged(UxThis);
}

void UxBase::SetCreateManaged(const char* val)
{
	UxPutCreateManaged(UxThis, (char *) val);
}

int UxBase::PopupInterface (grabtype grab)
{
	return UxPopupInterface(UxThis, grab);
}

int UxBase::PopdownInterface()
{
	return UxPopdownInterface(UxThis);
}

int UxBase::DestroyInterface()
{
	return UxDestroyInterface(UxThis);
}

swidget UxBase::GetUxThis(void) const
{
	return UxThis;
}

int UxBase::GET_int(binptr object, const char *id) const
{
	return UxGET_int(UxThis, object, (char *) id);
}

int UxBase::PUT_int(binptr object, const char *id, int val)
{
	return UxPUT_int(UxThis, object, (char *) id, val);
}

char UxBase::GET_char(binptr object, const char *id) const
{
	return UxGET_char(UxThis, object, (char *) id);
}

int UxBase::PUT_char(binptr object, const char *id, char val)
{
	return UxPUT_int(UxThis, object, (char *) id, val);
}

short UxBase::GET_short(binptr object, const char *id) const
{
	return UxGET_short(UxThis, object, (char *) id);
}

int UxBase::PUT_short(binptr object, const char *id, short val)
{
	return UxPUT_short(UxThis, object, (char *) id, val);
}

long UxBase::GET_long(binptr object, const char *id) const
{
	return UxGET_long(UxThis, object, (char *) id);
}

int UxBase::PUT_long(binptr object, const char *id, long val)
{
	return UxPUT_long(UxThis, object, (char *) id, val);
}

double UxBase::GET_float(binptr object, const char *id)const
{
	return UxXrtGET_double(UxThis, object, (char *) id);
}

int UxBase::PUT_float(binptr object, const char *id, double val)
{
	return UxXrtPUT_double(UxThis, object, (char *) id, val);
}

stringTable UxBase::GET_stringTable(binptr object,
						   const char *id) const
{
	return UxGET_stringTable(UxThis, object, (char *) id);
}

int UxBase::GET_stringTable(binptr object, const char *id,
					   stringTable val) const
{
	return UxPUT_stringTable(UxThis, object, (char *) id, val);
}

voidFunction UxBase::GET_voidFunction(binptr object,
						     const char *id) const
{
	return UxGET_voidFunction(UxThis, object, (char *) id);
}

int UxBase::PUT_voidFunction(binptr object, const char *id,
					    voidFunction val)
{
	return UxPUT_voidFunction(UxThis, object, (char *) id, val);
}

cardFunction UxBase::GET_cardFunction(binptr object,
						     const char * id) const
{
	return UxGET_cardFunction(UxThis, object, (char *) id);
}

int UxBase::PUT_cardFunction(binptr object, const char *id,
					    cardFunction val)
{
	return UxPUT_cardFunction(UxThis, object, (char *) id, val);
}

 
visualPointer UxBase::GET_visualPointer(binptr object,
						       const char *id) const
{
	return UxGET_visualPointer(UxThis, object, (char *) id);
}

int UxBase::PUT_visualPointer(binptr object, const char *id,
					     visualPointer val)
{
	return UxPUT_visualPointer(UxThis, object, (char *) id, val);
}

XmTextSource UxBase::GET_XmTextSource(binptr object,
						     const char *id) const
{
	return UxGET_XmTextSource(UxThis, object, (char *) id);
}

int UxBase::PUT_XmTextSource(binptr object, const char *id,
					    XmTextSource val)
{
	return UxPUT_XmTextSource(UxThis, object, (char *) id, val);
}

char *UxBase::GET_string(binptr object, const char *id) const
{
	return UxGET_string(UxThis, object, (char *) id);
}

int UxBase::PUT_string(binptr object, const char *id,
				      const char *val)
{
	return UxPUT_string(UxThis, object, (char *) id, val);
}

char *	UxBase::GetTopWidget (void) const
{
	return UxGET_string(UxThis,UxP_FormRD_topWidget,"topWidget");
}

void	UxBase::SetTopWidget (const char * val)
{
	UxPUT_string(UxThis,UxP_FormRD_topWidget,"topWidget", val);
}

void	UxBase::SetTopWidget (swidget val)
{
	UxPUT_string(UxThis,UxP_FormRD_topWidget,"topWidget", (char*)val);
}

int	UxBase::GetTopPosition (void) const
{
	return UxGET_int(UxThis,UxP_FormRD_topPosition,"topPosition");
}

void	UxBase::SetTopPosition ( int val)
{
	UxPUT_int(UxThis,UxP_FormRD_topPosition,"topPosition",val);
}

int	UxBase::GetTopOffset (void) const
{
	return UxGET_int(UxThis,UxP_FormRD_topOffset,"topOffset");
}

void	UxBase::SetTopOffset ( int val)
{
	UxPUT_int(UxThis,UxP_FormRD_topOffset,"topOffset",val);
}

char *	UxBase::GetTopAttachment (void) const
{
	return UxGET_string(UxThis,UxP_FormRD_topAttachment,"topAttachment");
}

void	UxBase::SetTopAttachment (const char * val)
{
	UxPUT_string(UxThis,UxP_FormRD_topAttachment,"topAttachment", val);
}

char *	UxBase::GetRightWidget (void) const
{
	return UxGET_string(UxThis,UxP_FormRD_rightWidget,"rightWidget");
}

void	UxBase::SetRightWidget (const char * val)
{
	UxPUT_string(UxThis,UxP_FormRD_rightWidget,"rightWidget", val);
}

void	UxBase::SetRightWidget (swidget val)
{
	UxPUT_string(UxThis,UxP_FormRD_rightWidget,"rightWidget", (char*)val);
}

int	UxBase::GetRightPosition (void) const
{
	return UxGET_int(UxThis,UxP_FormRD_rightPosition,"rightPosition");
}

void	UxBase::SetRightPosition ( int val)
{
	UxPUT_int(UxThis,UxP_FormRD_rightPosition,"rightPosition",val);
}

int	UxBase::GetRightOffset (void) const
{
	return UxGET_int(UxThis,UxP_FormRD_rightOffset,"rightOffset");
}

void	UxBase::SetRightOffset ( int val)
{
	UxPUT_int(UxThis,UxP_FormRD_rightOffset,"rightOffset",val);
}

char *	UxBase::GetRightAttachment (void) const
{
	return UxGET_string(UxThis,UxP_FormRD_rightAttachment,"rightAttachment");
}

void	UxBase::SetRightAttachment (const char * val)
{
	UxPUT_string(UxThis,UxP_FormRD_rightAttachment,"rightAttachment", val);
}
char *	UxBase::GetResizable (void) const
{
	return UxGET_string(UxThis,UxP_FormRD_resizable,"resizable");
}

void	UxBase::SetResizable (const char * val)
{
	UxPUT_string(UxThis,UxP_FormRD_resizable,"resizable", val);
}

char *	UxBase::GetLeftWidget (void) const
{
	return UxGET_string(UxThis,UxP_FormRD_leftWidget,"leftWidget");
}

void	UxBase::SetLeftWidget (swidget val)
{
	UxPUT_string(UxThis,UxP_FormRD_leftWidget,"leftWidget", (char*)val);
}

void	UxBase::SetLeftWidget (const char * val)
{
	UxPUT_string(UxThis,UxP_FormRD_leftWidget,"leftWidget", val);
}

int	UxBase::GetLeftPosition (void) const
{
	return UxGET_int(UxThis,UxP_FormRD_leftPosition,"leftPosition");
}

void	UxBase::SetLeftPosition ( int val)
{
	UxPUT_int(UxThis,UxP_FormRD_leftPosition,"leftPosition",val);
}

int	UxBase::GetLeftOffset (void) const
{
	return UxGET_int(UxThis,UxP_FormRD_leftOffset,"leftOffset");
}

void	UxBase::SetLeftOffset ( int val)
{
	UxPUT_int(UxThis,UxP_FormRD_leftOffset,"leftOffset",val);
}

char *	UxBase::GetLeftAttachment (void) const
{
	return UxGET_string(UxThis,UxP_FormRD_leftAttachment,"leftAttachment");
}

void	UxBase::SetLeftAttachment (const char * val)
{
	UxPUT_string(UxThis,UxP_FormRD_leftAttachment,"leftAttachment", val);
}

char *	UxBase::GetBottomWidget (void) const
{
	return UxGET_string(UxThis,UxP_FormRD_bottomWidget,"bottomWidget");
}

void	UxBase::SetBottomWidget (const char * val)
{
	UxPUT_string(UxThis,UxP_FormRD_bottomWidget,"bottomWidget",val);
}

void	UxBase::SetBottomWidget (swidget val)
{
	UxPUT_string(UxThis,UxP_FormRD_bottomWidget,"bottomWidget", (char*)val);
}

int	UxBase::GetBottomPosition (void) const
{
	return UxGET_int(UxThis,UxP_FormRD_bottomPosition,"bottomPosition");
}

void	UxBase::SetBottomPosition ( int val)
{
	UxPUT_int(UxThis,UxP_FormRD_bottomPosition,"bottomPosition",val);
}

int	UxBase::GetBottomOffset (void) const
{
	return UxGET_int(UxThis,UxP_FormRD_bottomOffset,"bottomOffset");
}

void	UxBase::SetBottomOffset ( int val)
{
	UxPUT_int(UxThis,UxP_FormRD_bottomOffset,"bottomOffset",val);
}

char *	UxBase::GetBottomAttachment (void) const
{
	return UxGET_string(UxThis,UxP_FormRD_bottomAttachment,"bottomAttachment");
}

void	UxBase::SetBottomAttachment (const char * val)
{
	UxPUT_string(UxThis,UxP_FormRD_bottomAttachment,"bottomAttachment",val);
}


// constraints supplied by the frame and inherited by it's children
char *	UxBase::GetChildVerticalAlignment (void) const
{
	return UxGET_string(UxThis,UxP_FrameRD_childVerticalAlignment,"childVerticalAlignment");
}

void	UxBase::SetChildVerticalAlignment (const char * val)
{
UxPUT_string(UxThis,UxP_FrameRD_childVerticalAlignment,"childVerticalAlignment",val);
}

int	UxBase::GetChildHorizontalSpacing (void) const
{
return UxGET_int(UxThis,UxP_FrameRD_childHorizontalSpacing,"childHorizontalSpacing");
}

void	UxBase::SetChildHorizontalSpacing ( int val)
{
	UxPUT_int(UxThis,UxP_FrameRD_childHorizontalSpacing,"childHorizontalSpacing",val);
}

char *	UxBase::GetChildHorizontalAlignment (void) const
{
	return UxGET_string(UxThis,UxP_FrameRD_childHorizontalAlignment,"childHorizontalAlignment");
}

void	UxBase::SetChildHorizontalAlignment (const char * val)
{
	UxPUT_string(UxThis,UxP_FrameRD_childHorizontalAlignment,"childHorizontalAlignment",val);
}

char *	UxBase::GetChildType (void) const
{
	return UxGET_string(UxThis,UxP_FrameRD_childType,"childType");
}

void	UxBase::SetChildType (const char * val)
{
	UxPUT_string(UxThis,UxP_FrameRD_childType,"childType",val);
}

// constraints supplied by the pane and inherited by it's children
char *	UxBase::GetSkipAdjust (void) const
{
	return UxGET_string(UxThis,UxP_PanedWindowRD_skipAdjust,"skipAdjust");
}

void	UxBase::SetSkipAdjust (const char * val)
{
	UxPUT_string(UxThis,UxP_PanedWindowRD_skipAdjust,"skipAdjust",val);
}

int	UxBase::GetPaneMinimum (void) const
{
	return UxGET_int(UxThis,UxP_PanedWindowRD_paneMinimum,"paneMinimum");
}

void	UxBase::SetPaneMinimum ( int val)
{
	UxPUT_int(UxThis,UxP_PanedWindowRD_paneMinimum,"paneMinimum",val);
}

int	UxBase::GetPaneMaximum (void) const
{
	return UxGET_int(UxThis,UxP_PanedWindowRD_paneMaximum,"paneMaximum");
}

void	UxBase::SetPaneMaximum ( int val)
{
	UxPUT_int(UxThis,UxP_PanedWindowRD_paneMaximum,"paneMaximum",val);
}

char *	UxBase::GetAllowResize (void) const
{
	return UxGET_string(UxThis,UxP_PanedWindowRD_allowResize,"allowResize");
}

void	UxBase::SetAllowResize (const char * val)
{
	UxPUT_string(UxThis,UxP_PanedWindowRD_allowResize,"allowResize",val);
}


// constraints supplied by both the pane and the rowcolumn
short	UxBase::GetPositionIndex (void) const
{
	return UxGET_short(UxThis,UxP_PanedWindowRD_positionIndex,"positionIndex");
}

void	UxBase::SetPositionIndex ( short val)
{
	UxPUT_short(UxThis,UxP_PanedWindowRD_positionIndex,"positionIndex",val);
}

#ifdef sgi
// constraints supplied by the grid  
char *	UxBase::GetResizeHorizontal (void) const
{
	return UxGET_string(UxThis,UxP_GridRD_resizeHorizontal,"resizeHorizontal");
}

void	UxBase::SetResizeHorizontal (const char * val)
{
	UxPUT_string(UxThis,UxP_GridRD_resizeHorizontal,"resizeHorizontal", val);
}

char *	UxBase::GetResizeVertical (void) const
{
	return UxGET_string(UxThis,UxP_GridRD_resizeVertical,"resizeVertical");
}

void	UxBase::SetResizeVertical (const char * val)
{
	UxPUT_string(UxThis,UxP_GridRD_resizeVertical,"resizeVertical", val);
}

int	UxBase::GetColumn (void) const
{
	return UxGET_int(UxThis,UxP_GridRD_column,"column");
}

void	UxBase::SetColumn ( int val)
{
	UxPUT_int(UxThis,UxP_GridRD_column,"column",val);
}

int	UxBase::GetRow (void) const
{
	return UxGET_int(UxThis,UxP_GridRD_row,"row");
}

void	UxBase::SetRow ( int val)
{
	UxPUT_int(UxThis,UxP_GridRD_row,"row",val);
}

char *	UxBase::GetGravity (void) const
{
	return UxGET_string(UxThis,UxP_GridRD_gravity,"gravity");
}

void	UxBase::SetGravity (const char * val)
{
	UxPUT_string(UxThis,UxP_GridRD_gravity,"gravity", val);
}

// constraints supplied by the springBox
int	UxBase::GetHorizontalSpring (void) const
{
	return UxGET_int(UxThis,UxP_SpringBoxRD_horizontalSpring,"horizontalSpring");
}

void	UxBase::SetHorizontalSpring ( int val)
{
	UxPUT_int(UxThis,UxP_SpringBoxRD_horizontalSpring,"horizontalSpring",val);
}

int	UxBase::GetVerticalSpring (void) const
{
	return UxGET_int(UxThis,UxP_SpringBoxRD_verticalSpring,"verticalSpring");
}

void	UxBase::SetVerticalSpring ( int val)
{
	UxPUT_int(UxThis,UxP_SpringBoxRD_verticalSpring,"verticalSpring",val);
}

int	UxBase::GetBottomSpring (void) const
{
	return UxGET_int(UxThis,UxP_SpringBoxRD_bottomSpring,"bottomSpring");
}

void	UxBase::SetBottomSpring ( int val)
{
	UxPUT_int(UxThis,UxP_SpringBoxRD_bottomSpring,"bottomSpring",val);
}

int	UxBase::GetTopSpring (void) const
{
	return UxGET_int(UxThis,UxP_SpringBoxRD_topSpring,"topSpring");
}

void	UxBase::SetTopSpring ( int val)
{
	UxPUT_int(UxThis,UxP_SpringBoxRD_topSpring,"topSpring",val);
}

int	UxBase::GetLeftSpring (void) const
{
	return UxGET_int(UxThis,UxP_SpringBoxRD_leftSpring,"leftSpring");
}

void	UxBase::SetLeftSpring ( int val)
{
	UxPUT_int(UxThis,UxP_SpringBoxRD_leftSpring,"leftSpring",val);
}

int	UxBase::GetRightSpring (void) const
{
	return UxGET_int(UxThis,UxP_SpringBoxRD_rightSpring,"rightSpring");
}

void	UxBase::SetRightSpring ( int val)
{
	UxPUT_int(UxThis,UxP_SpringBoxRD_rightSpring,"rightSpring",val);
}

#endif /* sgi */

#ifdef XRT

	/* include UxXrtBase.h which contains definitions
	 * for constraint methods in UxBase supplied by XRT widgets
	 */
#include <UxXrtBase.h>

#endif /* XRT */

void UxSwidget::AddCallback(const char* cname,
					XtCallbackProc cbproc,
					XtPointer cdata)
{
	UxAddCallback(UxThis, (char *) cname, cbproc, cdata);
}

void *UxSwidget::GetContext()
{
	return UxGetContext(UxThis);
}

int UxSwidget::SetContext(void *cntxt)
{
	return UxPutContext(UxThis, cntxt);
}

Widget   UxSwidget::CreateWidget()
{
	return UxCreateWidget(UxThis);
}

void     UxSwidget::DelayUpdate()
{
	UxDelayUpdate(UxThis);
}

void	UxSwidget::DestroySwidget()
{
	if (UxThis != NULL)
	{
		UxDestroySwidget(UxThis);
		UxThis = NULL;
	}
}

WidgetClass UxSwidget::GetClass() const
{
	return UxGetClass(UxThis);
}

int	UxSwidget::IsSwidget() const
{
	return UxIsSwidget(UxThis);
}

void	UxSwidget::Manage()
{
	UxManage(UxThis);
}

void	UxSwidget::Map()
{
	UxMap(UxThis);
}

swidget	UxSwidget::NameToSwidget(const char *val) const
{
	return UxNameToSwidget(UxThis, (char *) val);
}

int	UxSwidget::RealizeInterface()
{
	return UxRealizeInterface(UxThis);
}

Widget	UxSwidget::ShellWidget()
{
	return UxShellWidget(UxThis);
}

void	UxSwidget::Unmanage()
{
	UxUnmanage(UxThis);
}

void	UxSwidget::Unmap()
{
	UxUnmap(UxThis);
}

void	UxSwidget::Update()
{
	UxUpdate(UxThis);
}

WidgetClass UxSwidget::GetDefaultShell() const
{
	return UxGetDefaultShellClass(UxThis);
}

void	UxSwidget::SetDefaultShell(const char *val)
{
	UxPutDefaultShell(UxThis, (char *) val);
}

void	UxSwidget::MainWindowSetAreas
			(swidget pdmenu, swidget cmdw, swidget hsb,
						swidget vsb, swidget ww)
{
	UxMainWindowSetAreas(UxThis, pdmenu, cmdw, hsb, vsb, ww);
}


// Interface Class; implementation of the UXINLINE functions

void UxInterface::auto_destroy(Boolean value)
{
        auto_destroy_flag = value;
}

Boolean UxInterface::auto_destroy() const
{
        return auto_destroy_flag;
}

UxInterface::UxInterface(): auto_destroy_flag(False)
{
}
