/* $AstecId: XrtGph_restb.c,v 1.4 1999/10/13 11:47:59 nakayama Exp kosaka $ */
/* ALL RIGHTS RESERVED
 *
 * This file is provided for demonstration and educational uses only.
 * Permission to use, copy, modify and distribute this file for
 * any purpose and without fee is hereby granted, provided that the
 * above copyright notice and this permission notice appear in all
 * copies, and that the name of KL Group not be used in advertising
 * or publicity pertaining to this material without the specific,
 * prior written permission of an authorized representative of
 * KL Group.
 *
 * KL GROUP MAKES NO REPRESENTATIONS AND EXTENDS NO WARRANTIES, EX-
 * PRESS OR IMPLIED, WITH RESPECT TO THE SOFTWARE, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR ANY PARTICULAR PURPOSE, AND THE WARRANTY AGAINST IN-
 * FRINGEMENT OF PATENTS OR OTHER INTELLECTUAL PROPERTY RIGHTS.  THE
 * SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT SHALL KL GROUP OR
 * ANY OF ITS AFFILIATES BE LIABLE FOR ANY DAMAGES, INCLUDING ANY
 * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES
 * RELATING TO THE USE OF THIS SOFTWARE.
 *
 *
 * XRT/graph widget UIM/X integration file
 *
 *  SCCSID -- @(#)XrtGph_restb.c	1.20    99/02/01 KL Group Inc.
 */

/*****************************************************************************
				XrtGph_restb.c
*****************************************************************************/

#include <Xm/XrtGraph.h>		/* Widget-class public header file */
#include <UxLib.h>

#ifdef DESIGN_TIME

#include "veos.h"       		/* Visual Edge object system */
#include "valuesOf.h"   		/* ValuesOf & Validator functions */

#include "XrtGph.cl.h"

#else

#include "stub_runtime.h"

#endif /* DESIGN_TIME */

#include "XrtGph_xtype.h"
#include "Xrt_restable.h"

extern swidget UxGUIPopupColorView();
extern swidget UxGUIPopupFontView();
extern swidget UxPopupXrtData();

static int   XrtGphPutFloat();
static float XrtGphGetFloat();

XrtGphResourceDesc xrtgph_res_table[] = {
{ 
	"xrtAngleUnit",
	"RD_xrtAngleUnit",
	XtNxrtAngleUnit,
	"XtNxrtAngleUnit",
	XRTGPH_ANGLEUNIT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtAngleUnit),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumAngleUnit,
	FALSE,
	TRUE
},
{
	"xrtAxisBoundingBox",
	"RD_xrtAxisBoundingBox",
	XtNxrtAxisBoundingBox,
	"XtNxrtAxisBoundingBox",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtAxisBoundingBox),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumAxisBoundingBox,
	FALSE,
	TRUE
},
{
	"xrtAxisFont",
	"RD_xrtAxisFont",
	XtNxrtAxisFont,
	"XtNxrtAxisFont",
	XRTGPH_FONT_LIST,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtAxisFont),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumAxisFont,
	FALSE,
	TRUE
},
{
	"xrtBackgroundColor",
	"RD_xrtBackgroundColor",
	XtNxrtBackgroundColor,
	"XtNxrtBackgroundColor",
	XRTGPH_COLOR,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtBackgroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumBackgroundColor,
	FALSE,
	TRUE
},
{
	"xrtBarClusterOverlap",
	"RD_xrtBarClusterOverlap",
	XtNxrtBarClusterOverlap,
	"XtNxrtBarClusterOverlap",
	XRTGPH_INT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtBarClusterOverlap),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumBarClusterOverlap,
	FALSE,
	TRUE
},
{
	"xrtBarClusterWidth",
	"RD_xrtBarClusterWidth",
	XtNxrtBarClusterWidth,
	"XtNxrtBarClusterWidth",
	XRTGPH_INT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtBarClusterWidth),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumBarClusterWidth,
	FALSE,
	TRUE
},
{ 
	"xrtBorder",
	"RD_xrtBorder",
	XtNxrtBorder,
	"XtNxrtBorder",
	XRTGPH_BORDER,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtBorder),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumBorder,
	FALSE,
	TRUE
},
{ 
	"xrtCandleComplex",
	"RD_xrtCandleComplex",
	XtNxrtCandleComplex,
	"XtNxrtCandleComplex",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtCandleComplex),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumCandleComplex,
	FALSE,
	TRUE
},
{
	"xrtData",
	"RD_xrtData",
	XtNxrtData,
	"XtNxrtData",
	XRTGPH_DATA,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtData),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumData,
	FALSE,
	TRUE
},
{
	"xrtData2",
	"RD_xrtData2",
	XtNxrtData2,
	"XtNxrtData2",
	XRTGPH_DATA2,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtData2),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumData2,
	FALSE,
	TRUE
},
{
	"xrtDataAreaBackgroundColor",
	"RD_xrtDataAreaBackgroundColor",
	XtNxrtDataAreaBackgroundColor,
	"XtNxrtDataAreaBackgroundColor",
	XRTGPH_COLOR,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtDataAreaBackgroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumDataAreaBackgroundColor,
	FALSE,
	TRUE
},
{ 
	"xrtDataAreaForegroundColor",
	"RD_xrtDataAreaForegroundColor",
	XtNxrtDataAreaForegroundColor,
	"XtNxrtDataAreaForegroundColor",
	XRTGPH_COLOR,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtDataAreaForegroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumDataAreaForegroundColor,
	FALSE,
	TRUE
},
{
	"xrtDataStyles",
	"RD_xrtDataStyles",
	XtNxrtDataStyles,
	"XtNxrtDataStyles",
	XRTGPH_DATASTYLES,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtDataStyles),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumDataStyles,
	FALSE,
	TRUE
},
{
	"xrtDataStyles2",
	"RD_xrtDataStyles2",
	XtNxrtDataStyles2,
	"XtNxrtDataStyles2",
	XRTGPH_DATASTYLES,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtDataStyles2),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumDataStyles2,
	FALSE,
	TRUE
},
{
	"xrtDataStyles2UseDefault",
	"RD_xrtDataStyles2UseDefault",
	XtNxrtDataStyles2UseDefault,
	"XtNxrtDataStyles2UseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtDataStyles2UseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumDataStyles2UseDefault,
	FALSE,
	TRUE
},
{
	"xrtDataStylesUseDefault",
	"RD_xrtDataStylesUseDefault",
	XtNxrtDataStylesUseDefault,
	"XtNxrtDataStylesUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtDataStylesUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumDataStylesUseDefault,
	FALSE,
	TRUE
},
{
	"xrtDebug",
	"RD_xrtDebug",
	XtNxrtDebug,
	"XtNxrtDebug",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtDebug),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumDebug,
	FALSE,
	TRUE
},
{
	"xrtDoubleBuffer",
	"RD_xrtDoubleBuffer",
	XtNxrtDoubleBuffer,
	"XtNxrtDoubleBuffer",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtDoubleBuffer),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumDoubleBuffer,
	FALSE,
	TRUE
},
{
	"xrtExposeCallback",
	"RD_xrtExposeCallback",
	XtNxrtExposeCallback,
	"XtNxrtExposeCallback",
	XRTGPH_CALLBACK,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtExposeCallback),
	XRTDIV_BEHAVIOR,
	XRTPASS0,
	NULL,
	xrtResNumExposeCallback,
	FALSE,
	TRUE
},
{
	"xrtFooterAdjust",
	"RD_xrtFooterAdjust",
	XtNxrtFooterAdjust,
	"XtNxrtFooterAdjust",
	XRTGPH_ADJUST,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtFooterAdjust),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumFooterAdjust,
	FALSE,
	TRUE
},
{
	"xrtFooterBackgroundColor",
	"RD_xrtFooterBackgroundColor",
	XtNxrtFooterBackgroundColor,
	"XtNxrtFooterBackgroundColor",
	XRTGPH_COLOR,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtFooterBackgroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumFooterBackgroundColor,
	FALSE,
	TRUE
},
{
	"xrtFooterBorder",
	"RD_xrtFooterBorder",
	XtNxrtFooterBorder,
	"XtNxrtFooterBorder",
	XRTGPH_BORDER,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtFooterBorder),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumFooterBorder,
	FALSE,
	TRUE
},
{
	"xrtFooterBorderWidth",
	"RD_xrtFooterBorderWidth",
	XtNxrtFooterBorderWidth,
	"XtNxrtFooterBorderWidth",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtFooterBorderWidth),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumFooterBorderWidth,
	FALSE,
	TRUE
},
{
	"xrtFooterFont",
	"RD_xrtFooterFont",
	XtNxrtFooterFont,
	"XtNxrtFooterFont",
	XRTGPH_FONT_LIST,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtFooterFont),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumFooterFont,
	FALSE,
	TRUE
},
{
	"xrtFooterForegroundColor",
	"RD_xrtFooterForegroundColor",
	XtNxrtFooterForegroundColor,
	"XtNxrtFooterForegroundColor",
	XRTGPH_COLOR,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtFooterForegroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumFooterForegroundColor,
	FALSE,
	TRUE
},
{
	"xrtFooterHeight",
	"RD_xrtFooterHeight",
	XtNxrtFooterHeight,
	"XtNxrtFooterHeight",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtFooterHeight),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumFooterHeight,
	TRUE,
	TRUE
},
{
	"xrtFooterStrings",
	"RD_xrtFooterStrings",
	XtNxrtFooterStrings,
	"XtNxrtFooterStrings",
	XRTGPH_STRINGS,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtFooterStrings),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumFooterStrings,
	FALSE,
	TRUE
},
{
	"xrtFooterWidth",
	"RD_xrtFooterWidth",
	XtNxrtFooterWidth,
	"XtNxrtFooterWidth",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtFooterWidth),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumFooterWidth,
	TRUE,
	TRUE
},
{
	"xrtFooterX",
	"RD_xrtFooterX",
	XtNxrtFooterX,
	"XtNxrtFooterX",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtFooterX),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumFooterX,
	FALSE,
	TRUE
},
{
	"xrtFooterXUseDefault",
	"RD_xrtFooterXUseDefault",
	XtNxrtFooterXUseDefault,
	"XtNxrtFooterXUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtFooterXUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumFooterXUseDefault,
	FALSE,
	TRUE
},
{
	"xrtFooterY",
	"RD_xrtFooterY",
	XtNxrtFooterY,
	"XtNxrtFooterY",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtFooterY),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumFooterY,
	FALSE,
	TRUE
},
{
	"xrtFooterYUseDefault",
	"RD_xrtFooterYUseDefault",
	XtNxrtFooterYUseDefault,
	"XtNxrtFooterYUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtFooterYUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumFooterYUseDefault,
	FALSE,
	TRUE
},
{
	"xrtForegroundColor",
	"RD_xrtForegroundColor",
	XtNxrtForegroundColor,
	"XtNxrtForegroundColor",
	XRTGPH_COLOR,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtForegroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumForegroundColor,
	FALSE,
	TRUE
},
{
	"xrtFrontDataset",
	"RD_xrtFrontDataset",
	XtNxrtFrontDataset,
	"XtNxrtFrontDataset",
	XRTGPH_INT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtFrontDataset),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumFrontDataset,
	FALSE,
	TRUE
},
{ 
	"xrtGraph3dShading",
	"RD_xrtGraph3dShading",
	XtNxrtGraph3dShading,
	"XtNxrtGraph3dShading",
	XRTGPH_SHADING,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraph3dShading),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumGraph3dShading,
	FALSE,
	TRUE
},
{
	"xrtGraphBackgroundColor",
	"RD_xrtGraphBackgroundColor",
	XtNxrtGraphBackgroundColor,
	"XtNxrtGraphBackgroundColor",
	XRTGPH_COLOR,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphBackgroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumGraphBackgroundColor,
	FALSE,
	TRUE
},
{
	"xrtGraphBorder",
	"RD_xrtGraphBorder",
	XtNxrtGraphBorder,
	"XtNxrtGraphBorder",
	XRTGPH_BORDER,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphBorder),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumGraphBorder,
	FALSE,
	TRUE
},
{
	"xrtGraphBorderWidth",
	"RD_xrtGraphBorderWidth",
	XtNxrtGraphBorderWidth,
	"XtNxrtGraphBorderWidth",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphBorderWidth),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumGraphBorderWidth,
	FALSE,
	TRUE
},
{
	"xrtGraphDepth",
	"RD_xrtGraphDepth",
	XtNxrtGraphDepth,
	"XtNxrtGraphDepth",
	XRTGPH_INT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphDepth),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumGraphDepth,
	FALSE,
	TRUE
},
{
	"xrtGraphForegroundColor",
	"RD_xrtGraphForegroundColor",
	XtNxrtGraphForegroundColor,
	"XtNxrtGraphForegroundColor",
	XRTGPH_COLOR,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphForegroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumGraphForegroundColor,
	FALSE,
	TRUE
},
{
	"xrtGraphHeight",
	"RD_xrtGraphHeight",
	XtNxrtGraphHeight,
	"XtNxrtGraphHeight",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphHeight),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumGraphHeight,
	FALSE,
	TRUE
},
{
	"xrtGraphHeightUseDefault",
	"RD_xrtGraphHeightUseDefault",
	XtNxrtGraphHeightUseDefault,
	"XtNxrtGraphHeightUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphHeightUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumGraphHeightUseDefault,
	FALSE,
	TRUE
},
{
	"xrtGraphInclination",
	"RD_xrtGraphInclination",
	XtNxrtGraphInclination,
	"XtNxrtGraphInclination",
	XRTGPH_INT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphInclination),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumGraphInclination,
	FALSE,
	TRUE
},
{
	"xrtGraphMarginBottom",
	"RD_xrtGraphMarginBottom",
	XtNxrtGraphMarginBottom,
	"XtNxrtGraphMarginBottom",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphMarginBottom),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumGraphMarginBottom,
	FALSE,
	TRUE
},
{
	"xrtGraphMarginBottomUseDefault",
	"RD_xrtGraphMarginBottomUseDefault",
	XtNxrtGraphMarginBottomUseDefault,
	"XtNxrtGraphMarginBottomUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphMarginBottomUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumGraphMarginBottomUseDefault,
	FALSE,
	TRUE
},
{
	"xrtGraphMarginLeft",
	"RD_xrtGraphMarginLeft",
	XtNxrtGraphMarginLeft,
	"XtNxrtGraphMarginLeft",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphMarginLeft),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumGraphMarginLeft,
	FALSE,
	TRUE
},
{
	"xrtGraphMarginLeftUseDefault",
	"RD_xrtGraphMarginLeftUseDefault",
	XtNxrtGraphMarginLeftUseDefault,
	"XtNxrtGraphMarginLeftUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphMarginLeftUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumGraphMarginLeftUseDefault,
	FALSE,
	TRUE
},
{
	"xrtGraphMarginRight",
	"RD_xrtGraphMarginRight",
	XtNxrtGraphMarginRight,
	"XtNxrtGraphMarginRight",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphMarginRight),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumGraphMarginRight,
	FALSE,
	TRUE
},
{
	"xrtGraphMarginRightUseDefault",
	"RD_xrtGraphMarginRightUseDefault",
	XtNxrtGraphMarginRightUseDefault,
	"XtNxrtGraphMarginRightUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphMarginRightUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumGraphMarginRightUseDefault,
	FALSE,
	TRUE
},
{
	"xrtGraphMarginTop",
	"RD_xrtGraphMarginTop",
	XtNxrtGraphMarginTop,
	"XtNxrtGraphMarginTop",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphMarginTop),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumGraphMarginTop,
	FALSE,
	TRUE
},
{
	"xrtGraphMarginTopUseDefault",
	"RD_xrtGraphMarginTopUseDefault",
	XtNxrtGraphMarginTopUseDefault,
	"XtNxrtGraphMarginTopUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphMarginTopUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumGraphMarginTopUseDefault,
	FALSE,
	TRUE
},
{
	"xrtGraphRotation",
	"RD_xrtGraphRotation",
	XtNxrtGraphRotation,
	"XtNxrtGraphRotation",
	XRTGPH_INT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphRotation),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumGraphRotation,
	FALSE,
	TRUE
},
{ 
	"xrtGraphShowOutlines",
	"RD_xrtGraphShowOutlines",
	XtNxrtGraphShowOutlines,
	"XtNxrtGraphShowOutlines",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphShowOutlines),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumGraphShowOutlines,
	FALSE,
	TRUE
},
{
	"xrtGraphWidth",
	"RD_xrtGraphWidth",
	XtNxrtGraphWidth,
	"XtNxrtGraphWidth",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphWidth),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumGraphWidth,
	FALSE,
	TRUE
},
{
	"xrtGraphWidthUseDefault",
	"RD_xrtGraphWidthUseDefault",
	XtNxrtGraphWidthUseDefault,
	"XtNxrtGraphWidthUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphWidthUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumGraphWidthUseDefault,
	FALSE,
	TRUE
},
{
	"xrtGraphX",
	"RD_xrtGraphX",
	XtNxrtGraphX,
	"XtNxrtGraphX",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphX),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumGraphX,
	FALSE,
	TRUE
},
{
	"xrtGraphXUseDefault",
	"RD_xrtGraphXUseDefault",
	XtNxrtGraphXUseDefault,
	"XtNxrtGraphXUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphXUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumGraphXUseDefault,
	FALSE,
	TRUE
},
{
	"xrtGraphY",
	"RD_xrtGraphY",
	XtNxrtGraphY,
	"XtNxrtGraphY",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphY),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumGraphY,
	FALSE,
	TRUE
},
{
	"xrtGraphYUseDefault",
	"RD_xrtGraphYUseDefault",
	XtNxrtGraphYUseDefault,
	"XtNxrtGraphYUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphYUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumGraphYUseDefault,
	FALSE,
	TRUE
},
{
	"xrtHeaderAdjust",
	"RD_xrtHeaderAdjust",
	XtNxrtHeaderAdjust,
	"XtNxrtHeaderAdjust",
	XRTGPH_ADJUST,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtHeaderAdjust),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumHeaderAdjust,
	FALSE,
	TRUE
},
{
	"xrtHeaderBackgroundColor",
	"RD_xrtHeaderBackgroundColor",
	XtNxrtHeaderBackgroundColor,
	"XtNxrtHeaderBackgroundColor",
	XRTGPH_COLOR,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtHeaderBackgroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumHeaderBackgroundColor,
	FALSE,
	TRUE
},
{
	"xrtHeaderBorder",
	"RD_xrtHeaderBorder",
	XtNxrtHeaderBorder,
	"XtNxrtHeaderBorder",
	XRTGPH_BORDER,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtHeaderBorder),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumHeaderBorder,
	FALSE,
	TRUE
},
{
	"xrtHeaderBorderWidth",
	"RD_xrtHeaderBorderWidth",
	XtNxrtHeaderBorderWidth,
	"XtNxrtHeaderBorderWidth",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtHeaderBorderWidth),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumHeaderBorderWidth,
	FALSE,
	TRUE
},
{
	"xrtHeaderFont",
	"RD_xrtHeaderFont",
	XtNxrtHeaderFont,
	"XtNxrtHeaderFont",
	XRTGPH_FONT_LIST,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtHeaderFont),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumHeaderFont,
	FALSE,
	TRUE
},
{
	"xrtHeaderForegroundColor",
	"RD_xrtHeaderForegroundColor",
	XtNxrtHeaderForegroundColor,
	"XtNxrtHeaderForegroundColor",
	XRTGPH_COLOR,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtHeaderForegroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumHeaderForegroundColor,
	FALSE,
	TRUE
},
{
	"xrtHeaderHeight",
	"RD_xrtHeaderHeight",
	XtNxrtHeaderHeight,
	"XtNxrtHeaderHeight",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtHeaderHeight),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumHeaderHeight,
	TRUE,
	TRUE
},
{
	"xrtHeaderStrings",
	"RD_xrtHeaderStrings",
	XtNxrtHeaderStrings,
	"XtNxrtHeaderStrings",
	XRTGPH_STRINGS,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtHeaderStrings),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumHeaderStrings,
	FALSE,
	TRUE
},
{
	"xrtHeaderWidth",
	"RD_xrtHeaderWidth",
	XtNxrtHeaderWidth,
	"XtNxrtHeaderWidth",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtHeaderWidth),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumHeaderWidth,
	TRUE,
	TRUE
},
{
	"xrtHeaderX",
	"RD_xrtHeaderX",
	XtNxrtHeaderX,
	"XtNxrtHeaderX",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtHeaderX),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumHeaderX,
	FALSE,
	TRUE
},
{
	"xrtHeaderXUseDefault",
	"RD_xrtHeaderXUseDefault",
	XtNxrtHeaderXUseDefault,
	"XtNxrtHeaderXUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtHeaderXUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumHeaderXUseDefault,
	FALSE,
	TRUE
},
{
	"xrtHeaderY",
	"RD_xrtHeaderY",
	XtNxrtHeaderY,
	"XtNxrtHeaderY",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtHeaderY),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumHeaderY,
	FALSE,
	TRUE
},
{
	"xrtHeaderYUseDefault",
	"RD_xrtHeaderYUseDefault",
	XtNxrtHeaderYUseDefault,
	"XtNxrtHeaderYUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtHeaderYUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumHeaderYUseDefault,
	FALSE,
	TRUE
},
{ 
	"xrtHiLoCloseShow",
	"RD_xrtHiLoCloseShow",
	XtNxrtHiLoCloseShow,
	"XtNxrtHiLoCloseShow",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtHiLoCloseShow),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumHiLoCloseShow,
	FALSE,
	TRUE
},
{ 
	"xrtHiLoOpenCloseFullWidth",
	"RD_xrtHiLoOpenCloseFullWidth",
	XtNxrtHiLoOpenCloseFullWidth,
	"XtNxrtHiLoOpenCloseFullWidth",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtHiLoOpenCloseFullWidth),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumHiLoOpenCloseFullWidth,
	FALSE,
	TRUE
},
{ 
	"xrtHiLoOpenShow",
	"RD_xrtHiLoOpenShow",
	XtNxrtHiLoOpenShow,
	"XtNxrtHiLoOpenShow",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtHiLoOpenShow),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumHiLoOpenShow,
	FALSE,
	TRUE
},
{
	"xrtInvertOrientation",
	"RD_xrtInvertOrientation",
	XtNxrtInvertOrientation,
	"XtNxrtInvertOrientation",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtInvertOrientation),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumInvertOrientation,
	FALSE,
	TRUE
},
{
	"xrtLegendAnchor",
	"RD_xrtLegendAnchor",
	XtNxrtLegendAnchor,
	"XtNxrtLegendAnchor",
	XRTGPH_ANCHOR,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtLegendAnchor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumLegendAnchor,
	FALSE,
	TRUE
},
{
	"xrtLegendBackgroundColor",
	"RD_xrtLegendBackgroundColor",
	XtNxrtLegendBackgroundColor,
	"XtNxrtLegendBackgroundColor",
	XRTGPH_COLOR,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtLegendBackgroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumLegendBackgroundColor,
	FALSE,
	TRUE
},
{
	"xrtLegendBorder",
	"RD_xrtLegendBorder",
	XtNxrtLegendBorder,
	"XtNxrtLegendBorder",
	XRTGPH_BORDER,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtLegendBorder),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumLegendBorder,
	FALSE,
	TRUE
},
{
	"xrtLegendBorderWidth",
	"RD_xrtLegendBorderWidth",
	XtNxrtLegendBorderWidth,
	"XtNxrtLegendBorderWidth",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtLegendBorderWidth),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumLegendBorderWidth,
	FALSE,
	TRUE
},
{
	"xrtLegendFont",
	"RD_xrtLegendFont",
	XtNxrtLegendFont,
	"XtNxrtLegendFont",
	XRTGPH_FONT_LIST,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtLegendFont),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumLegendFont,
	FALSE,
	TRUE
},
{
	"xrtLegendForegroundColor",
	"RD_xrtLegendForegroundColor",
	XtNxrtLegendForegroundColor,
	"XtNxrtLegendForegroundColor",
	XRTGPH_COLOR,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtLegendForegroundColor),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumLegendForegroundColor,
	FALSE,
	TRUE
},
{
	"xrtLegendHeight",
	"RD_xrtLegendHeight",
	XtNxrtLegendHeight,
	"XtNxrtLegendHeight",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtLegendHeight),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumLegendHeight,
	TRUE,
	TRUE
},
{
	"xrtLegendOrientation",
	"RD_xrtLegendOrientation",
	XtNxrtLegendOrientation,
	"XtNxrtLegendOrientation",
	XRTGPH_ALIGN,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtLegendOrientation),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumLegendOrientation,
	FALSE,
	TRUE
},
{
	"xrtLegendShow",
	"RD_xrtLegendShow",
	XtNxrtLegendShow,
	"XtNxrtLegendShow",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtLegendShow),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumLegendShow,
	FALSE,
	TRUE
},
{
	"xrtLegendWidth",
	"RD_xrtLegendWidth",
	XtNxrtLegendWidth,
	"XtNxrtLegendWidth",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtLegendWidth),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumLegendWidth,
	TRUE,
	TRUE
},
{
	"xrtLegendX",
	"RD_xrtLegendX",
	XtNxrtLegendX,
	"XtNxrtLegendX",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtLegendX),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumLegendX,
	FALSE,
	TRUE
},
{
	"xrtLegendXUseDefault",
	"RD_xrtLegendXUseDefault",
	XtNxrtLegendXUseDefault,
	"XtNxrtLegendXUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtLegendXUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumLegendXUseDefault,
	FALSE,
	TRUE
},
{
	"xrtLegendY",
	"RD_xrtLegendY",
	XtNxrtLegendY,
	"XtNxrtLegendY",
	XRTGPH_SHORT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtLegendY),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumLegendY,
	FALSE,
	TRUE
},
{
	"xrtLegendYUseDefault",
	"RD_xrtLegendYUseDefault",
	XtNxrtLegendYUseDefault,
	"XtNxrtLegendYUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtLegendYUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumLegendYUseDefault,
	FALSE,
	TRUE
},
{
	"xrtMapCallback",
	"RD_xrtMapCallback",
	XtNxrtMapCallback,
	"XtNxrtMapCallback",
	XRTGPH_CALLBACK,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtMapCallback),
	XRTDIV_BEHAVIOR,
	XRTPASS0,
	NULL,
	xrtResNumMapCallback,
	FALSE,
	TRUE
},
{
	"xrtMarkerDataStyle",
	"RD_xrtMarkerDataStyle",
	XtNxrtMarkerDataStyle,
	"XtNxrtMarkerDataStyle",
	XRTGPH_DATASTYLE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtMarkerDataStyle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumMarkerDataStyle,
	FALSE,
	TRUE
},
{
	"xrtMarkerDataStyleUseDefault",
	"RD_xrtMarkerDataStyleUseDefault",
	XtNxrtMarkerDataStyleUseDefault,
	"XtNxrtMarkerDataStyleUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtMarkerDataStyleUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumMarkerDataStyleUseDefault,
	FALSE,
	TRUE
},
{
	"xrtMarkerDataset",
	"RD_xrtMarkerDataset",
	XtNxrtMarkerDataset,
	"XtNxrtMarkerDataset",
	XRTGPH_INT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtMarkerDataset),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumMarkerDataset,
	FALSE,
	TRUE
},
{
	"xrtModifyCallback",
	"RD_xrtModifyCallback",
	XtNxrtModifyCallback,
	"XtNxrtModifyCallback",
	XRTGPH_CALLBACK,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtModifyCallback),
	XRTDIV_BEHAVIOR,
	XRTPASS2,
	NULL,
	xrtResNumModifyCallback,
	FALSE,
	TRUE
},
{
	"xrtOtherDataStyle",
	"RD_xrtOtherDataStyle",
	XtNxrtOtherDataStyle,
	"XtNxrtOtherDataStyle",
	XRTGPH_DATASTYLE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtOtherDataStyle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumOtherDataStyle,
	FALSE,
	TRUE
},
{
	"xrtOtherDataStyleUseDefault",
	"RD_xrtOtherDataStyleUseDefault",
	XtNxrtOtherDataStyleUseDefault,
	"XtNxrtOtherDataStyleUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtOtherDataStyleUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumOtherDataStyleUseDefault,
	FALSE,
	TRUE
},
{
	"xrtOtherLabel",
	"RD_xrtOtherLabel",
	XtNxrtOtherLabel,
	"XtNxrtOtherLabel",
	XRTGPH_STRING,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtOtherLabel),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumOtherLabel,
	FALSE,
	TRUE
},
{
	"xrtPickCallback",
	"RD_xrtPickCallback",
	XtNxrtPickCallback,
	"XtNxrtPickCallback",
	XRTGPH_CALLBACK,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtPickCallback),
	XRTDIV_BEHAVIOR,
	XRTPASS0,
	NULL,
	xrtResNumPickCallback,
	FALSE,
	TRUE
},
{
	"xrtPieMinSlices",
	"RD_xrtPieMinSlices",
	XtNxrtPieMinSlices,
	"XtNxrtPieMinSlices",
	XRTGPH_INT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtPieMinSlices),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumPieMinSlices,
	FALSE,
	TRUE
},
{
	"xrtPieOrder",
	"RD_xrtPieOrder",
	XtNxrtPieOrder,
	"XtNxrtPieOrder",
	XRTGPH_PIEORDER,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtPieOrder),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumPieOrder,
	FALSE,
	TRUE
},
{
	"xrtPieThresholdMethod",
	"RD_xrtPieThresholdMethod",
	XtNxrtPieThresholdMethod,
	"XtNxrtPieThresholdMethod",
	XRTGPH_PIETHRESHOLDMETHOD,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtPieThresholdMethod),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumPieThresholdMethod,
	FALSE,
	TRUE
},
{
	"xrtPieThresholdValue",
	"RD_xrtPieThresholdValue",
	XtNxrtPieThresholdValue,
	"XtNxrtPieThresholdValue",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtPieThresholdValue),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumPieThresholdValue,
	FALSE,
	TRUE
},
{
	"xrtPointLabels",
	"RD_xrtPointLabels",
	XtNxrtPointLabels,
	"XtNxrtPointLabels",
	XRTGPH_STRINGS,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtPointLabels),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumPointLabels,
	FALSE,
	TRUE
},
{
	"xrtPointLabels2",
	"RD_xrtPointLabels2",
	XtNxrtPointLabels2,
	"XtNxrtPointLabels2",
	XRTGPH_STRINGS,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtPointLabels2),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumPointLabels2,
	FALSE,
	TRUE
},
{ 
	"xrtPolarHalfRange",
	"RD_xrtPolarHalfRange",
	XtNxrtPolarHalfRange,
	"XtNxrtPolarHalfRange",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtPolarHalfRange),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumPolarHalfRange,
	FALSE,
	TRUE
},
{
	"xrtRepaint",
	"RD_xrtRepaint",
	XtNxrtRepaint,
	"XtNxrtRepaint",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtRepaint),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumRepaint,
	FALSE,
	FALSE
},
{
	"xrtResizeCallback",
	"RD_xrtResizeCallback",
	XtNxrtResizeCallback,
	"XtNxrtResizeCallback",
	XRTGPH_CALLBACK,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtResizeCallback),
	XRTDIV_BEHAVIOR,
	XRTPASS2,
	NULL,
	xrtResNumResizeCallback,
	FALSE,
	TRUE
},
{
	"xrtRotateCallback",
	"RD_xrtRotateCallback",
	XtNxrtRotateCallback,
	"XtNxrtRotateCallback",
	XRTGPH_CALLBACK,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtRotateCallback),
	XRTDIV_BEHAVIOR,
	XRTPASS2,
	NULL,
	xrtResNumRotateCallback,
	FALSE,
	TRUE
},
{
	"xrtSetLabels",
	"RD_xrtSetLabels",
	XtNxrtSetLabels,
	"XtNxrtSetLabels",
	XRTGPH_STRINGS,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtSetLabels),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumSetLabels,
	FALSE,
	TRUE
},
{
	"xrtSetLabels2",
	"RD_xrtSetLabels2",
	XtNxrtSetLabels2,
	"XtNxrtSetLabels2",
	XRTGPH_STRINGS,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtSetLabels2),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumSetLabels2,
	FALSE,
	TRUE
},
{
	"xrtTimeBase",
	"RD_xrtTimeBase",
	XtNxrtTimeBase,
	"XtNxrtTimeBase",
	XRTGPH_LONG,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtTimeBase),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumTimeBase,
	FALSE,
	TRUE
},
{
	"xrtTimeFormat",
	"RD_xrtTimeFormat",
	XtNxrtTimeFormat,
	"XtNxrtTimeFormat",
	XRTGPH_STRING,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtTimeFormat),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumTimeFormat,
	FALSE,
	TRUE
},
{
	"xrtTimeFormatUseDefault",
	"RD_xrtTimeFormatUseDefault",
	XtNxrtTimeFormatUseDefault,
	"XtNxrtTimeFormatUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtTimeFormatUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumTimeFormatUseDefault,
	FALSE,
	TRUE
},
{
	"xrtTimeUnit",
	"RD_xrtTimeUnit",
	XtNxrtTimeUnit,
	"XtNxrtTimeUnit",
	XRTGPH_TIMEUNIT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtTimeUnit),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumTimeUnit,
	FALSE,
	TRUE
},
{
	"xrtTransformCallback",
	"RD_xrtTransformCallback",
	XtNxrtTransformCallback,
	"XtNxrtTransformCallback",
	XRTGPH_CALLBACK,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtTransformCallback),
	XRTDIV_BEHAVIOR,
	XRTPASS2,
	NULL,
	xrtResNumTransformCallback,
	FALSE,
	TRUE
},
{
	"xrtType",
	"RD_xrtType",
	XtNxrtType,
	"XtNxrtType",
	XRTGPH_TYPE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtType),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumType,
	FALSE,
	TRUE
},
{
	"xrtType2",
	"RD_xrtType2",
	XtNxrtType2,
	"XtNxrtType2",
	XRTGPH_TYPE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtType2),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumType2,
	FALSE,
	TRUE
},
{
	"xrtXAnnoPlacement",
	"RD_xrtXAnnoPlacement",
	XtNxrtXAnnoPlacement,
	"XtNxrtXAnnoPlacement",
	XRTGPH_ANNOPLACEMENT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXAnnoPlacement),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXAnnoPlacement,
	FALSE,
	TRUE
},
{
	"xrtXAnnotationMethod",
	"RD_xrtXAnnotationMethod",
	XtNxrtXAnnotationMethod,
	"XtNxrtXAnnotationMethod",
	XRTGPH_ANNOTATIONMETHOD,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXAnnotationMethod),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXAnnotationMethod,
	FALSE,
	TRUE
},
{
	"xrtXAnnotationRotation",
	"RD_xrtXAnnotationRotation",
	XtNxrtXAnnotationRotation,
	"XtNxrtXAnnotationRotation",
	XRTGPH_ROTATE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXAnnotationRotation),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXAnnotationRotation,
	FALSE,
	TRUE
},
{ 
	"xrtXAxisLabelFormat",
	"RD_xrtXAxisLabelFormat",
	XtNxrtXAxisLabelFormat,
	"XtNxrtXAxisLabelFormat",
	XRTGPH_STRING,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXAxisLabelFormat),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXAxisLabelFormat,
	FALSE,
	TRUE
},
{
	"xrtXAxisLogarithmic",
	"RD_xrtXAxisLogarithmic",
	XtNxrtXAxisLogarithmic,
	"XtNxrtXAxisLogarithmic",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXAxisLogarithmic),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumXAxisLogarithmic,
	FALSE,
	TRUE
},
{
	"xrtXAxisMax",
	"RD_xrtXAxisMax",
	XtNxrtXAxisMax,
	"XtNxrtXAxisMax",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXAxisMax),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXAxisMax,
	FALSE,
	TRUE
},
{
	"xrtXAxisMaxUseDefault",
	"RD_xrtXAxisMaxUseDefault",
	XtNxrtXAxisMaxUseDefault,
	"XtNxrtXAxisMaxUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXAxisMaxUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumXAxisMaxUseDefault,
	FALSE,
	TRUE
},
{
	"xrtXAxisMin",
	"RD_xrtXAxisMin",
	XtNxrtXAxisMin,
	"XtNxrtXAxisMin",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXAxisMin),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXAxisMin,
	FALSE,
	TRUE
},
{
	"xrtXAxisMinUseDefault",
	"RD_xrtXAxisMinUseDefault",
	XtNxrtXAxisMinUseDefault,
	"XtNxrtXAxisMinUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXAxisMinUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumXAxisMinUseDefault,
	FALSE,
	TRUE
},
{
	"xrtXAxisReversed",
	"RD_xrtXAxisReversed",
	XtNxrtXAxisReversed,
	"XtNxrtXAxisReversed",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXAxisReversed),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumXAxisReversed,
	FALSE,
	TRUE
},
{
	"xrtXAxisShow",
	"RD_xrtXAxisShow",
	XtNxrtXAxisShow,
	"XtNxrtXAxisShow",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXAxisShow),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumXAxisShow,
	FALSE,
	TRUE
},
{
	"xrtXGrid",
	"RD_xrtXGrid",
	XtNxrtXGrid,
	"XtNxrtXGrid",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXGrid),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXGrid,
	FALSE,
	TRUE
},
{
	"xrtXGridDataStyle",
	"RD_xrtXGridDataStyle",
	XtNxrtXGridDataStyle,
	"XtNxrtXGridDataStyle",
	XRTGPH_DATASTYLE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXGridDataStyle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXGridDataStyle,
	FALSE,
	TRUE
},
{
	"xrtXGridDataStyleUseDefault",
	"RD_xrtXGridDataStyleUseDefault",
	XtNxrtXGridDataStyleUseDefault,
	"XtNxrtXGridDataStyleUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXGridDataStyleUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumXGridDataStyleUseDefault,
	FALSE,
	TRUE
},
{
	"xrtXGridUseDefault",
	"RD_xrtXGridUseDefault",
	XtNxrtXGridUseDefault,
	"XtNxrtXGridUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXGridUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumXGridUseDefault,
	FALSE,
	TRUE
},
{
	"xrtXLabels",
	"RD_xrtXLabels",
	XtNxrtXLabels,
	"XtNxrtXLabels",
	XRTGPH_VALUELABELS,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXLabels),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXLabels,
	FALSE,
	TRUE
},
{
	"xrtXMarker",
	"RD_xrtXMarker",
	XtNxrtXMarker,
	"XtNxrtXMarker",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXMarker),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumXMarker,
	FALSE,
	TRUE
},
{ 
	"xrtXMarkerDataStyle",
	"RD_xrtXMarkerDataStyle",
	XtNxrtXMarkerDataStyle,
	"XtNxrtXMarkerDataStyle",
	XRTGPH_DATASTYLE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXMarkerDataStyle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXMarkerDataStyle,
	FALSE,
	TRUE
},
{ 
	"xrtXMarkerDataStyleUseDefault",
	"RD_xrtXMarkerDataStyleUseDefault",
	XtNxrtXMarkerDataStyleUseDefault,
	"XtNxrtXMarkerDataStyleUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXMarkerDataStyleUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXMarkerDataStyleUseDefault,
	FALSE,
	TRUE
},
{ 
	"xrtXMarkerMethod",
	"RD_xrtXMarkerMethod",
	XtNxrtXMarkerMethod,
	"XtNxrtXMarkerMethod",
	XRTGPH_MARKERMETHOD,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXMarkerMethod),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXMarkerMethod,
	FALSE,
	TRUE
},
{
	"xrtXMarkerPoint",
	"RD_xrtXMarkerPoint",
	XtNxrtXMarkerPoint,
	"XtNxrtXMarkerPoint",
	XRTGPH_INT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXMarkerPoint),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumXMarkerPoint,
	FALSE,
	TRUE
},
{
	"xrtXMarkerSet",
	"RD_xrtXMarkerSet",
	XtNxrtXMarkerSet,
	"XtNxrtXMarkerSet",
	XRTGPH_INT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXMarkerSet),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumXMarkerSet,
	FALSE,
	TRUE
},
{
	"xrtXMarkerShow",
	"RD_xrtXMarkerShow",
	XtNxrtXMarkerShow,
	"XtNxrtXMarkerShow",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXMarkerShow),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumXMarkerShow,
	FALSE,
	TRUE
},
{
	"xrtXMax",
	"RD_xrtXMax",
	XtNxrtXMax,
	"XtNxrtXMax",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXMax),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXMax,
	FALSE,
	TRUE
},
{
	"xrtXMaxUseDefault",
	"RD_xrtXMaxUseDefault",
	XtNxrtXMaxUseDefault,
	"XtNxrtXMaxUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXMaxUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumXMaxUseDefault,
	FALSE,
	TRUE
},
{
	"xrtXMin",
	"RD_xrtXMin",
	XtNxrtXMin,
	"XtNxrtXMin",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXMin),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXMin,
	FALSE,
	TRUE
},
{
	"xrtXMinUseDefault",
	"RD_xrtXMinUseDefault",
	XtNxrtXMinUseDefault,
	"XtNxrtXMinUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXMinUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumXMinUseDefault,
	FALSE,
	TRUE
},
{
	"xrtXNum",
	"RD_xrtXNum",
	XtNxrtXNum,
	"XtNxrtXNum",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXNum),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXNum,
	FALSE,
	TRUE
},
{
	"xrtXNumMethod",
	"RD_xrtXNumMethod",
	XtNxrtXNumMethod,
	"XtNxrtXNumMethod",
	XRTGPH_NUMMETHOD,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXNumMethod),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXNumMethod,
	FALSE,
	TRUE
},
{
	"xrtXNumUseDefault",
	"RD_xrtXNumUseDefault",
	XtNxrtXNumUseDefault,
	"XtNxrtXNumUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXNumUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumXNumUseDefault,
	FALSE,
	TRUE
},
{
	"xrtXOrigin",
	"RD_xrtXOrigin",
	XtNxrtXOrigin,
	"XtNxrtXOrigin",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXOrigin),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXOrigin,
	FALSE,
	TRUE
},
{ 
	"xrtXOriginBase",
	"RD_xrtXOriginBase",
	XtNxrtXOriginBase,
	"XtNxrtXOriginBase",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXOriginBase),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXOriginBase,
	FALSE,
	TRUE
},
{
	"xrtXOriginPlacement",
	"RD_xrtXOriginPlacement",
	XtNxrtXOriginPlacement,
	"XtNxrtXOriginPlacement",
	XRTGPH_ORIGINPLACEMENT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXOriginPlacement),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXOriginPlacement,
	FALSE,
	TRUE
},
{
	"xrtXOriginUseDefault",
	"RD_xrtXOriginUseDefault",
	XtNxrtXOriginUseDefault,
	"XtNxrtXOriginUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXOriginUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumXOriginUseDefault,
	FALSE,
	TRUE
},
{
	"xrtXPrecision",
	"RD_xrtXPrecision",
	XtNxrtXPrecision,
	"XtNxrtXPrecision",
	XRTGPH_INT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXPrecision),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXPrecision,
	FALSE,
	TRUE
},
{
	"xrtXPrecisionUseDefault",
	"RD_xrtXPrecisionUseDefault",
	XtNxrtXPrecisionUseDefault,
	"XtNxrtXPrecisionUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXPrecisionUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumXPrecisionUseDefault,
	FALSE,
	TRUE
},
{
	"xrtXTick",
	"RD_xrtXTick",
	XtNxrtXTick,
	"XtNxrtXTick",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXTick),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXTick,
	FALSE,
	TRUE
},
{
	"xrtXTickUseDefault",
	"RD_xrtXTickUseDefault",
	XtNxrtXTickUseDefault,
	"XtNxrtXTickUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXTickUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumXTickUseDefault,
	FALSE,
	TRUE
},
{
	"xrtXTitle",
	"RD_xrtXTitle",
	XtNxrtXTitle,
	"XtNxrtXTitle",
	XRTGPH_STRING,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXTitle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXTitle,
	FALSE,
	TRUE
},
{
	"xrtXTitleRotation",
	"RD_xrtXTitleRotation",
	XtNxrtXTitleRotation,
	"XtNxrtXTitleRotation",
	XRTGPH_ROTATE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXTitleRotation),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXTitleRotation,
	FALSE,
	TRUE
},
{ 
	"xrtY2AnnoPlacement",
	"RD_xrtY2AnnoPlacement",
	XtNxrtY2AnnoPlacement,
	"XtNxrtY2AnnoPlacement",
	XRTGPH_ANNOPLACEMENT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2AnnoPlacement),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2AnnoPlacement,
	FALSE,
	TRUE
},
{ 
	"xrtY2AnnotationAngle",
	"RD_xrtY2AnnotationAngle",
	XtNxrtY2AnnotationAngle,
	"XtNxrtY2AnnotationAngle",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2AnnotationAngle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2AnnotationAngle,
	FALSE,
	TRUE
},
{ 
	"xrtY2AnnotationAngleUseDefault",
	"RD_xrtY2AnnotationAngleUseDefault",
	XtNxrtY2AnnotationAngleUseDefault,
	"XtNxrtY2AnnotationAngleUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2AnnotationAngleUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2AnnotationAngleUseDefault,
	FALSE,
	TRUE
},
{
	"xrtY2AnnotationMethod",
	"RD_xrtY2AnnotationMethod",
	XtNxrtY2AnnotationMethod,
	"XtNxrtY2AnnotationMethod",
	XRTGPH_ANNOTATIONMETHOD,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2AnnotationMethod),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2AnnotationMethod,
	FALSE,
	TRUE
},
{
	"xrtY2AnnotationRotation",
	"RD_xrtY2AnnotationRotation",
	XtNxrtY2AnnotationRotation,
	"XtNxrtY2AnnotationRotation",
	XRTGPH_ROTATE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2AnnotationRotation),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2AnnotationRotation,
	FALSE,
	TRUE
},
{ 
	"xrtY2Axis100Percent",
	"RD_xrtY2Axis100Percent",
	XtNxrtY2Axis100Percent,
	"XtNxrtY2Axis100Percent",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2Axis100Percent),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2Axis100Percent,
	FALSE,
	TRUE
},
{ 
	"xrtY2AxisLabelFormat",
	"RD_xrtY2AxisLabelFormat",
	XtNxrtY2AxisLabelFormat,
	"XtNxrtY2AxisLabelFormat",
	XRTGPH_STRING,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2AxisLabelFormat),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2AxisLabelFormat,
	FALSE,
	TRUE
},
{
	"xrtY2AxisLogarithmic",
	"RD_xrtY2AxisLogarithmic",
	XtNxrtY2AxisLogarithmic,
	"XtNxrtY2AxisLogarithmic",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2AxisLogarithmic),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumY2AxisLogarithmic,
	FALSE,
	TRUE
},
{
	"xrtY2AxisMax",
	"RD_xrtY2AxisMax",
	XtNxrtY2AxisMax,
	"XtNxrtY2AxisMax",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2AxisMax),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2AxisMax,
	FALSE,
	TRUE
},
{
	"xrtY2AxisMaxUseDefault",
	"RD_xrtY2AxisMaxUseDefault",
	XtNxrtY2AxisMaxUseDefault,
	"XtNxrtY2AxisMaxUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2AxisMaxUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumY2AxisMaxUseDefault,
	FALSE,
	TRUE
},
{
	"xrtY2AxisMin",
	"RD_xrtY2AxisMin",
	XtNxrtY2AxisMin,
	"XtNxrtY2AxisMin",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2AxisMin),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2AxisMin,
	FALSE,
	TRUE
},
{
	"xrtY2AxisMinUseDefault",
	"RD_xrtY2AxisMinUseDefault",
	XtNxrtY2AxisMinUseDefault,
	"XtNxrtY2AxisMinUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2AxisMinUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumY2AxisMinUseDefault,
	FALSE,
	TRUE
},
{
	"xrtY2AxisReversed",
	"RD_xrtY2AxisReversed",
	XtNxrtY2AxisReversed,
	"XtNxrtY2AxisReversed",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2AxisReversed),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumY2AxisReversed,
	FALSE,
	TRUE
},
{
	"xrtY2AxisShow",
	"RD_xrtY2AxisShow",
	XtNxrtY2AxisShow,
	"XtNxrtY2AxisShow",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2AxisShow),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumY2AxisShow,
	FALSE,
	TRUE
},
{ 
	"xrtY2Grid",
	"RD_xrtY2Grid",
	XtNxrtY2Grid,
	"XtNxrtY2Grid",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2Grid),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2Grid,
	FALSE,
	TRUE
},
{ 
	"xrtY2GridDataStyle",
	"RD_xrtY2GridDataStyle",
	XtNxrtY2GridDataStyle,
	"XtNxrtY2GridDataStyle",
	XRTGPH_DATASTYLE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2GridDataStyle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2GridDataStyle,
	FALSE,
	TRUE
},
{ 
	"xrtY2GridDataStyleUseDefault",
	"RD_xrtY2GridDataStyleUseDefault",
	XtNxrtY2GridDataStyleUseDefault,
	"XtNxrtY2GridDataStyleUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2GridDataStyleUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2GridDataStyleUseDefault,
	FALSE,
	TRUE
},
{ 
	"xrtY2GridUseDefault",
	"RD_xrtY2GridUseDefault",
	XtNxrtY2GridUseDefault,
	"XtNxrtY2GridUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2GridUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2GridUseDefault,
	FALSE,
	TRUE
},
{
	"xrtY2Labels",
	"RD_xrtY2Labels",
	XtNxrtY2Labels,
	"XtNxrtY2Labels",
	XRTGPH_VALUELABELS,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2Labels),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2Labels,
	FALSE,
	TRUE
},
{
	"xrtY2Max",
	"RD_xrtY2Max",
	XtNxrtY2Max,
	"XtNxrtY2Max",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2Max),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2Max,
	FALSE,
	TRUE
},
{
	"xrtY2MaxUseDefault",
	"RD_xrtY2MaxUseDefault",
	XtNxrtY2MaxUseDefault,
	"XtNxrtY2MaxUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2MaxUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumY2MaxUseDefault,
	FALSE,
	TRUE
},
{
	"xrtY2Min",
	"RD_xrtY2Min",
	XtNxrtY2Min,
	"XtNxrtY2Min",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2Min),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2Min,
	FALSE,
	TRUE
},
{
	"xrtY2MinUseDefault",
	"RD_xrtY2MinUseDefault",
	XtNxrtY2MinUseDefault,
	"XtNxrtY2MinUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2MinUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumY2MinUseDefault,
	FALSE,
	TRUE
},
{
	"xrtY2Num",
	"RD_xrtY2Num",
	XtNxrtY2Num,
	"XtNxrtY2Num",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2Num),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2Num,
	FALSE,
	TRUE
},
{
	"xrtY2NumMethod",
	"RD_xrtY2NumMethod",
	XtNxrtY2NumMethod,
	"XtNxrtY2NumMethod",
	XRTGPH_NUMMETHOD,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2NumMethod),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2NumMethod,
	FALSE,
	TRUE
},
{
	"xrtY2NumUseDefault",
	"RD_xrtY2NumUseDefault",
	XtNxrtY2NumUseDefault,
	"XtNxrtY2NumUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2NumUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumY2NumUseDefault,
	FALSE,
	TRUE
},
{ 
	"xrtY2Origin",
	"RD_xrtY2Origin",
	XtNxrtY2Origin,
	"XtNxrtY2Origin",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2Origin),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2Origin,
	FALSE,
	TRUE
},
{ 
	"xrtY2OriginPlacement",
	"RD_xrtY2OriginPlacement",
	XtNxrtY2OriginPlacement,
	"XtNxrtY2OriginPlacement",
	XRTGPH_ORIGINPLACEMENT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2OriginPlacement),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2OriginPlacement,
	FALSE,
	TRUE
},
{ 
	"xrtY2OriginUseDefault",
	"RD_xrtY2OriginUseDefault",
	XtNxrtY2OriginUseDefault,
	"XtNxrtY2OriginUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2OriginUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2OriginUseDefault,
	FALSE,
	TRUE
},
{
	"xrtY2Precision",
	"RD_xrtY2Precision",
	XtNxrtY2Precision,
	"XtNxrtY2Precision",
	XRTGPH_INT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2Precision),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2Precision,
	FALSE,
	TRUE
},
{
	"xrtY2PrecisionUseDefault",
	"RD_xrtY2PrecisionUseDefault",
	XtNxrtY2PrecisionUseDefault,
	"XtNxrtY2PrecisionUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2PrecisionUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumY2PrecisionUseDefault,
	FALSE,
	TRUE
},
{
	"xrtY2Tick",
	"RD_xrtY2Tick",
	XtNxrtY2Tick,
	"XtNxrtY2Tick",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2Tick),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2Tick,
	FALSE,
	TRUE
},
{
	"xrtY2TickUseDefault",
	"RD_xrtY2TickUseDefault",
	XtNxrtY2TickUseDefault,
	"XtNxrtY2TickUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2TickUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumY2TickUseDefault,
	FALSE,
	TRUE
},
{
	"xrtY2Title",
	"RD_xrtY2Title",
	XtNxrtY2Title,
	"XtNxrtY2Title",
	XRTGPH_STRING,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2Title),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2Title,
	FALSE,
	TRUE
},
{
	"xrtY2TitleRotation",
	"RD_xrtY2TitleRotation",
	XtNxrtY2TitleRotation,
	"XtNxrtY2TitleRotation",
	XRTGPH_ROTATE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2TitleRotation),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2TitleRotation,
	FALSE,
	TRUE
},
{
	"xrtYAnnoPlacement",
	"RD_xrtYAnnoPlacement",
	XtNxrtYAnnoPlacement,
	"XtNxrtYAnnoPlacement",
	XRTGPH_ANNOPLACEMENT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYAnnoPlacement),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYAnnoPlacement,
	FALSE,
	TRUE
},
{ 
	"xrtYAnnotationAngle",
	"RD_xrtYAnnotationAngle",
	XtNxrtYAnnotationAngle,
	"XtNxrtYAnnotationAngle",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYAnnotationAngle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYAnnotationAngle,
	FALSE,
	TRUE
},
{ 
	"xrtYAnnotationAngleUseDefault",
	"RD_xrtYAnnotationAngleUseDefault",
	XtNxrtYAnnotationAngleUseDefault,
	"XtNxrtYAnnotationAngleUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYAnnotationAngleUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYAnnotationAngleUseDefault,
	FALSE,
	TRUE
},
{
	"xrtYAnnotationMethod",
	"RD_xrtYAnnotationMethod",
	XtNxrtYAnnotationMethod,
	"XtNxrtYAnnotationMethod",
	XRTGPH_ANNOTATIONMETHOD,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYAnnotationMethod),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYAnnotationMethod,
	FALSE,
	TRUE
},
{
	"xrtYAnnotationRotation",
	"RD_xrtYAnnotationRotation",
	XtNxrtYAnnotationRotation,
	"XtNxrtYAnnotationRotation",
	XRTGPH_ROTATE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYAnnotationRotation),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYAnnotationRotation,
	FALSE,
	TRUE
},
{ 
	"xrtYAxis100Percent",
	"RD_xrtYAxis100Percent",
	XtNxrtYAxis100Percent,
	"XtNxrtYAxis100Percent",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYAxis100Percent),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYAxis100Percent,
	FALSE,
	TRUE
},
{
	"xrtYAxisConst",
	"RD_xrtYAxisConst",
	XtNxrtYAxisConst,
	"XtNxrtYAxisConst",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYAxisConst),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumYAxisConst,
	FALSE,
	TRUE
},
{ 
	"xrtYAxisLabelFormat",
	"RD_xrtYAxisLabelFormat",
	XtNxrtYAxisLabelFormat,
	"XtNxrtYAxisLabelFormat",
	XRTGPH_STRING,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYAxisLabelFormat),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYAxisLabelFormat,
	FALSE,
	TRUE
},
{
	"xrtYAxisLogarithmic",
	"RD_xrtYAxisLogarithmic",
	XtNxrtYAxisLogarithmic,
	"XtNxrtYAxisLogarithmic",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYAxisLogarithmic),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumYAxisLogarithmic,
	FALSE,
	TRUE
},
{
	"xrtYAxisMax",
	"RD_xrtYAxisMax",
	XtNxrtYAxisMax,
	"XtNxrtYAxisMax",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYAxisMax),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYAxisMax,
	FALSE,
	TRUE
},
{
	"xrtYAxisMaxUseDefault",
	"RD_xrtYAxisMaxUseDefault",
	XtNxrtYAxisMaxUseDefault,
	"XtNxrtYAxisMaxUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYAxisMaxUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumYAxisMaxUseDefault,
	FALSE,
	TRUE
},
{
	"xrtYAxisMin",
	"RD_xrtYAxisMin",
	XtNxrtYAxisMin,
	"XtNxrtYAxisMin",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYAxisMin),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYAxisMin,
	FALSE,
	TRUE
},
{
	"xrtYAxisMinUseDefault",
	"RD_xrtYAxisMinUseDefault",
	XtNxrtYAxisMinUseDefault,
	"XtNxrtYAxisMinUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYAxisMinUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumYAxisMinUseDefault,
	FALSE,
	TRUE
},
{
	"xrtYAxisMult",
	"RD_xrtYAxisMult",
	XtNxrtYAxisMult,
	"XtNxrtYAxisMult",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYAxisMult),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumYAxisMult,
	FALSE,
	TRUE
},
{
	"xrtYAxisReversed",
	"RD_xrtYAxisReversed",
	XtNxrtYAxisReversed,
	"XtNxrtYAxisReversed",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYAxisReversed),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumYAxisReversed,
	FALSE,
	TRUE
},
{
	"xrtYAxisShow",
	"RD_xrtYAxisShow",
	XtNxrtYAxisShow,
	"XtNxrtYAxisShow",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYAxisShow),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumYAxisShow,
	FALSE,
	TRUE
},
{
	"xrtYGrid",
	"RD_xrtYGrid",
	XtNxrtYGrid,
	"XtNxrtYGrid",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYGrid),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYGrid,
	FALSE,
	TRUE
},
{
	"xrtYGridDataStyle",
	"RD_xrtYGridDataStyle",
	XtNxrtYGridDataStyle,
	"XtNxrtYGridDataStyle",
	XRTGPH_DATASTYLE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYGridDataStyle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYGridDataStyle,
	FALSE,
	TRUE
},
{
	"xrtYGridDataStyleUseDefault",
	"RD_xrtYGridDataStyleUseDefault",
	XtNxrtYGridDataStyleUseDefault,
	"XtNxrtYGridDataStyleUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYGridDataStyleUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumYGridDataStyleUseDefault,
	FALSE,
	TRUE
},
{
	"xrtYGridUseDefault",
	"RD_xrtYGridUseDefault",
	XtNxrtYGridUseDefault,
	"XtNxrtYGridUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYGridUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumYGridUseDefault,
	FALSE,
	TRUE
},
{
	"xrtYLabels",
	"RD_xrtYLabels",
	XtNxrtYLabels,
	"XtNxrtYLabels",
	XRTGPH_VALUELABELS,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYLabels),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYLabels,
	FALSE,
	TRUE
},
{
	"xrtYMarker",
	"RD_xrtYMarker",
	XtNxrtYMarker,
	"XtNxrtYMarker",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYMarker),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumYMarker,
	FALSE,
	TRUE
},
{ 
	"xrtYMarkerDataStyle",
	"RD_xrtYMarkerDataStyle",
	XtNxrtYMarkerDataStyle,
	"XtNxrtYMarkerDataStyle",
	XRTGPH_DATASTYLE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYMarkerDataStyle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYMarkerDataStyle,
	FALSE,
	TRUE
},
{ 
	"xrtYMarkerDataStyleUseDefault",
	"RD_xrtYMarkerDataStyleUseDefault",
	XtNxrtYMarkerDataStyleUseDefault,
	"XtNxrtYMarkerDataStyleUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYMarkerDataStyleUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYMarkerDataStyleUseDefault,
	FALSE,
	TRUE
},
{
	"xrtYMarkerShow",
	"RD_xrtYMarkerShow",
	XtNxrtYMarkerShow,
	"XtNxrtYMarkerShow",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYMarkerShow),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumYMarkerShow,
	FALSE,
	TRUE
},
{
	"xrtYMax",
	"RD_xrtYMax",
	XtNxrtYMax,
	"XtNxrtYMax",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYMax),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYMax,
	FALSE,
	TRUE
},
{
	"xrtYMaxUseDefault",
	"RD_xrtYMaxUseDefault",
	XtNxrtYMaxUseDefault,
	"XtNxrtYMaxUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYMaxUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumYMaxUseDefault,
	FALSE,
	TRUE
},
{
	"xrtYMin",
	"RD_xrtYMin",
	XtNxrtYMin,
	"XtNxrtYMin",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYMin),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYMin,
	FALSE,
	TRUE
},
{
	"xrtYMinUseDefault",
	"RD_xrtYMinUseDefault",
	XtNxrtYMinUseDefault,
	"XtNxrtYMinUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYMinUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumYMinUseDefault,
	FALSE,
	TRUE
},
{
	"xrtYNum",
	"RD_xrtYNum",
	XtNxrtYNum,
	"XtNxrtYNum",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYNum),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYNum,
	FALSE,
	TRUE
},
{
	"xrtYNumMethod",
	"RD_xrtYNumMethod",
	XtNxrtYNumMethod,
	"XtNxrtYNumMethod",
	XRTGPH_NUMMETHOD,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYNumMethod),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYNumMethod,
	FALSE,
	TRUE
},
{
	"xrtYNumUseDefault",
	"RD_xrtYNumUseDefault",
	XtNxrtYNumUseDefault,
	"XtNxrtYNumUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYNumUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumYNumUseDefault,
	FALSE,
	TRUE
},
{
	"xrtYOrigin",
	"RD_xrtYOrigin",
	XtNxrtYOrigin,
	"XtNxrtYOrigin",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYOrigin),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYOrigin,
	FALSE,
	TRUE
},
{
	"xrtYOriginPlacement",
	"RD_xrtYOriginPlacement",
	XtNxrtYOriginPlacement,
	"XtNxrtYOriginPlacement",
	XRTGPH_ORIGINPLACEMENT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYOriginPlacement),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYOriginPlacement,
	FALSE,
	TRUE
},
{
	"xrtYOriginUseDefault",
	"RD_xrtYOriginUseDefault",
	XtNxrtYOriginUseDefault,
	"XtNxrtYOriginUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYOriginUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumYOriginUseDefault,
	FALSE,
	TRUE
},
{
	"xrtYPrecision",
	"RD_xrtYPrecision",
	XtNxrtYPrecision,
	"XtNxrtYPrecision",
	XRTGPH_INT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYPrecision),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYPrecision,
	FALSE,
	TRUE
},
{
	"xrtYPrecisionUseDefault",
	"RD_xrtYPrecisionUseDefault",
	XtNxrtYPrecisionUseDefault,
	"XtNxrtYPrecisionUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYPrecisionUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumYPrecisionUseDefault,
	FALSE,
	TRUE
},
{
	"xrtYTick",
	"RD_xrtYTick",
	XtNxrtYTick,
	"XtNxrtYTick",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYTick),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYTick,
	FALSE,
	TRUE
},
{
	"xrtYTickUseDefault",
	"RD_xrtYTickUseDefault",
	XtNxrtYTickUseDefault,
	"XtNxrtYTickUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYTickUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumYTickUseDefault,
	FALSE,
	TRUE
},
{
	"xrtYTitle",
	"RD_xrtYTitle",
	XtNxrtYTitle,
	"XtNxrtYTitle",
	XRTGPH_STRING,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYTitle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYTitle,
	FALSE,
	TRUE
},
{
	"xrtYTitleRotation",
	"RD_xrtYTitleRotation",
	XtNxrtYTitleRotation,
	"XtNxrtYTitleRotation",
	XRTGPH_ROTATE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYTitleRotation),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYTitleRotation,
	FALSE,
	TRUE
},
{ 
	"xrtZoomAxisCallback",
	"RD_xrtZoomAxisCallback",
	XtNxrtZoomAxisCallback,
	"XtNxrtZoomAxisCallback",
	XRTGPH_CALLBACK,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtZoomAxisCallback),
	XRTDIV_BEHAVIOR,
	XRTPASS0,
	NULL,
	xrtResNumZoomAxisCallback,
	FALSE,
	TRUE
},
{
	"xrtBubbleMax",
	"RD_xrtBubbleMax",
	XtNxrtBubbleMax,
	"XtNxrtBubbleMax",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtBubbleMax),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumBubbleMax,
	FALSE,
	TRUE
},
{
	"xrtBubbleMethod",
	"RD_xrtBubbleMethod",
	XtNxrtBubbleMethod,
	"XtNxrtBubbleMethod",
	XRTGPH_BUBBLEMETHOD,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtBubbleMethod),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumBubbleMethod,
	FALSE,
	TRUE
},
{
	"xrtBubbleMin",
	"RD_xrtBubbleMin",
	XtNxrtBubbleMin,
	"XtNxrtBubbleMin",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtBubbleMin),
	XRTDIV_SPECIFIC,
	XRTPASS2,
	NULL,
	xrtResNumBubbleMin,
	FALSE,
	TRUE
},
{
	"xrtColorFunc",
	"RD_xrtColorFunc",
	XtNxrtColorFunc,
	"XtNxrtColorFunc",
	XRTGPH_VOIDFUNCTION,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtColorFunc),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumColorFunc,
	FALSE,
	TRUE
},
{
	"xrtExtraDefaultDataStyles",
	"RD_xrtExtraDefaultDataStyles",
	XtNxrtExtraDefaultDataStyles,
	"XtNxrtExtraDefaultDataStyles",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtExtraDefaultDataStyles),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumExtraDefaultDataStyles,
	FALSE,
	TRUE
},
{
	"xrtFooterImage",
	"RD_xrtFooterImage",
	XtNxrtFooterImage,
	"XtNxrtFooterImage",
	XRTGPH_IMAGE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtFooterImage),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumFooterImage,
	FALSE,
	TRUE
},
{
	"xrtFooterImageLayout",
	"RD_xrtFooterImageLayout",
	XtNxrtFooterImageLayout,
	"XtNxrtFooterImageLayout",
	XRTGPH_IMAGELAYOUT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtFooterImageLayout),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumFooterImageLayout,
	FALSE,
	TRUE
},
{
	"xrtFooterImageMinimumSize",
	"RD_xrtFooterImageMinimumSize",
	XtNxrtFooterImageMinimumSize,
	"XtNxrtFooterImageMinimumSize",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtFooterImageMinimumSize),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumFooterImageMinimumSize,
	FALSE,
	TRUE
},
{
	"xrtDataAreaImage",
	"RD_xrtDataAreaImage",
	XtNxrtDataAreaImage,
	"XtNxrtDataAreaImage",
	XRTGPH_IMAGE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtDataAreaImage),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumDataAreaImage,
	FALSE,
	TRUE
},
{
	"xrtDataAreaImageLayout",
	"RD_xrtDataAreaImageLayout",
	XtNxrtDataAreaImageLayout,
	"XtNxrtDataAreaImageLayout",
	XRTGPH_IMAGELAYOUT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtDataAreaImageLayout),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumDataAreaImageLayout,
	FALSE,
	TRUE
},
{
	"xrtGraphImage",
	"RD_xrtGraphImage",
	XtNxrtGraphImage,
	"XtNxrtGraphImage",
	XRTGPH_IMAGE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphImage),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumGraphImage,
	FALSE,
	TRUE
},
{
	"xrtGraphImageLayout",
	"RD_xrtGraphImageLayout",
	XtNxrtGraphImageLayout,
	"XtNxrtGraphImageLayout",
	XRTGPH_IMAGELAYOUT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtGraphImageLayout),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumGraphImageLayout,
	FALSE,
	TRUE
},
{
	"xrtHeaderImage",
	"RD_xrtHeaderImage",
	XtNxrtHeaderImage,
	"XtNxrtHeaderImage",
	XRTGPH_IMAGE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtHeaderImage),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumHeaderImage,
	FALSE,
	TRUE
},
{
	"xrtHeaderImageLayout",
	"RD_xrtHeaderImageLayout",
	XtNxrtHeaderImageLayout,
	"XtNxrtHeaderImageLayout",
	XRTGPH_IMAGELAYOUT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtHeaderImageLayout),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumHeaderImageLayout,
	FALSE,
	TRUE
},
{
	"xrtHeaderImageMinimumSize",
	"RD_xrtHeaderImageMinimumSize",
	XtNxrtHeaderImageMinimumSize,
	"XtNxrtHeaderImageMinimumSize",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtHeaderImageMinimumSize),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumHeaderImageMinimumSize,
	FALSE,
	TRUE
},
{
	"xrtImage",
	"RD_xrtImage",
	XtNxrtImage,
	"XtNxrtImage",
	XRTGPH_IMAGE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtImage),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumImage,
	FALSE,
	TRUE
},
{
	"xrtImageLayout",
	"RD_xrtImageLayout",
	XtNxrtImageLayout,
	"XtNxrtImageLayout",
	XRTGPH_IMAGELAYOUT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtImageLayout),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumImageLayout,
	FALSE,
	TRUE
},
{
	"xrtIsStacked",
	"RD_xrtIsStacked",
	XtNxrtIsStacked,
	"XtNxrtIsStacked",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtIsStacked),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumIsStacked,
	FALSE,
	TRUE
},
{
	"xrtIsStacked2",
	"RD_xrtIsStacked2",
	XtNxrtIsStacked2,
	"XtNxrtIsStacked2",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtIsStacked2),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumIsStacked2,
	FALSE,
	TRUE
},
{
	"xrtLegendImage",
	"RD_xrtLegendImage",
	XtNxrtLegendImage,
	"XtNxrtLegendImage",
	XRTGPH_IMAGE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtLegendImage),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumLegendImage,
	FALSE,
	TRUE
},
{
	"xrtLegendImageLayout",
	"RD_xrtLegendImageLayout",
	XtNxrtLegendImageLayout,
	"XtNxrtLegendImageLayout",
	XRTGPH_IMAGELAYOUT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtLegendImageLayout),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumLegendImageLayout,
	FALSE,
	TRUE
},
{
	"xrtLegendReversed",
	"RD_xrtLegendReversed",
	XtNxrtLegendReversed,
	"XtNxrtLegendReversed",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtLegendReversed),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumLegendReversed,
	FALSE,
	TRUE
},
{
	"xrtLegendTitle",
	"RD_xrtLegendTitle",
	XtNxrtLegendTitle,
	"XtNxrtLegendTitle",
	XRTGPH_STRING,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtLegendTitle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumLegendTitle,
	FALSE,
	TRUE
},
{
	"xrtPieMergeMissingSlices",
	"RD_xrtPieMergeMissingSlices",
	XtNxrtPieMergeMissingSlices,
	"XtNxrtPieMergeMissingSlices",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtPieMergeMissingSlices),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumPieMergeMissingSlices,
	FALSE,
	TRUE
},
{
	"xrtPieStartAngle",
	"RD_xrtPieStartAngle",
	XtNxrtPieStartAngle,
	"XtNxrtPieStartAngle",
	XRTGPH_FLOAT,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtPieStartAngle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumPieStartAngle,
	FALSE,
	TRUE
},
{
	"xrtPolarAxisAllowNegatives",
	"RD_xrtPolarAxisAllowNegatives",
	XtNxrtPolarAxisAllowNegatives,
	"XtNxrtPolarAxisAllowNegatives",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtPolarAxisAllowNegatives),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumPolarAxisAllowNegatives,
	FALSE,
	TRUE
},
{
	"xrtXAxisDataStyle",
	"RD_xrtXAxisDataStyle",
	XtNxrtXAxisDataStyle,
	"XtNxrtXAxisDataStyle",
	XRTGPH_DATASTYLE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXAxisDataStyle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXAxisDataStyle,
	FALSE,
	TRUE
},
{
	"xrtXAxisDataStyleUseDefault",
	"RD_xrtXAxisDataStyleUseDefault",
	XtNxrtXAxisDataStyleUseDefault,
	"XtNxrtXAxisDataStyleUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtXAxisDataStyleUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumXAxisDataStyleUseDefault,
	FALSE,
	TRUE
},
{
	"xrtY2AxisDataStyle",
	"RD_xrtY2AxisDataStyle",
	XtNxrtY2AxisDataStyle,
	"XtNxrtY2AxisDataStyle",
	XRTGPH_DATASTYLE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2AxisDataStyle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2AxisDataStyle,
	FALSE,
	TRUE
},
{
	"xrtY2AxisDataStyleUseDefault",
	"RD_xrtY2AxisDataStyleUseDefault",
	XtNxrtY2AxisDataStyleUseDefault,
	"XtNxrtY2AxisDataStyleUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtY2AxisDataStyleUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumY2AxisDataStyleUseDefault,
	FALSE,
	TRUE
},
{
	"xrtYAxisDataStyle",
	"RD_xrtYAxisDataStyle",
	XtNxrtYAxisDataStyle,
	"XtNxrtYAxisDataStyle",
	XRTGPH_DATASTYLE,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYAxisDataStyle),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYAxisDataStyle,
	FALSE,
	TRUE
},
{
	"xrtYAxisDataStyleUseDefault",
	"RD_xrtYAxisDataStyleUseDefault",
	XtNxrtYAxisDataStyleUseDefault,
	"XtNxrtYAxisDataStyleUseDefault",
	XRTGPH_BOOL,
	{0, 0, 0},
	Offset(UxXrtGraphClass, XrtGraph.RD_xrtYAxisDataStyleUseDefault),
	XRTDIV_SPECIFIC,
	XRTPASS0,
	NULL,
	xrtResNumYAxisDataStyleUseDefault,
	FALSE,
	TRUE
}
};

int numgph_res = (sizeof(xrtgph_res_table) / sizeof(xrtgph_res_table[0]));

XrtResourceType **xrtgph_res_types = NULL;
int				numgph_res_types;

void
XrtGph_init_resource_types()
{
	XrtResourceType	*type;
	int				n;
	static Boolean	AlreadyDone = FALSE;
	
	if (AlreadyDone) {
		return;
	}

	n = 0;
	xrtgph_res_types = (XrtResourceType **)
		calloc(n+2, sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_BOOL;
	type->utype = UxUT_string;
	type->xtype = UxXT_Boolean;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfBoolean;
	type->validate = UxValidateBoolean;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_CALLBACK;
	type->utype = (short) 0;
	type->xtype = 0;
	type->convert_flag = 0;
	type->converter = NULL;
	type->values_of = NULL;
	type->validate = NULL;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_COLOR;
	type->utype = UxUT_string;
	type->xtype = UxXT_String;
	type->convert_flag = 0;
	type->converter = NULL;
	type->values_of = UxValuesOfString;
	type->validate = UxValidateString;
	type->edit_func = UxGUIPopupColorView;
	type->get_func = NULL;
	type->put_func = NULL;
 	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_FLOAT;
	type->utype = UxUT_float;
	type->xtype = UxXT_float;
	type->convert_flag = 0;
	type->converter = "UxConvertXrtGphFloat";
	type->values_of = UxValuesOfFloat;
	type->validate = UxValidateInt;
	type->edit_func = NULL;
	type->get_func = (int (*)())XrtGphGetFloat;
	type->put_func = XrtGphPutFloat;
	xrtgph_res_types[n++] = type;
			
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_FONT_LIST;
	type->utype = UxUT_string;
	type->xtype = UxXT_XmFontList;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXmFontList;
	type->validate = UxValidateXmFontList;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_LONG;
	type->utype = UxUT_long;
	type->xtype = UxXT_int;
	type->convert_flag = 0;
	type->converter = "UxConvertXrtGphLong";
	type->values_of = UxValuesOfInt;
	type->validate = UxValidateInt;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_INT;
	type->utype = UxUT_int;
	type->xtype = UxXT_int;
	type->convert_flag = 0;
	type->converter = NULL;
	type->values_of = UxValuesOfInt;
	type->validate = UxValidateInt;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_SHORT;
	type->utype = UxUT_short;
	type->xtype = UxXT_short;
	type->convert_flag = 0;
	type->converter = NULL;
	type->values_of = UxValuesOfInt;
	type->validate = UxValidateInt;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_STRING;
	type->utype = UxUT_string;
	type->xtype = UxXT_String;
	type->convert_flag = 0;
	type->converter = NULL;
	type->values_of = UxValuesOfString;
	type->validate = UxValidateString;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;

#if 0
rb:	this is old XFONT stuff
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_XFONT;
	type->utype = UxUT_string;
#ifdef USE_XRTGRAPH_FONTSET
	type->xtype = UxXT_XFontSet;
	type->values_of = UxValuesOfFontSet;
	type->validate = UxValidateFontSet;
#else
	type->xtype = UxXT_XFont;
	type->values_of = UxValuesOfFontStruct;
	type->validate = UxValidateFontStruct;
#endif /* USE_XRTGRAPH_FONTSET */
	type->convert_flag = 1;
	type->converter = NULL;
	type->edit_func = UxGUIPopupFontView;
	type->get_func = NULL;
	type->put_func = NULL;
 	xrtgph_res_types[n++] = type;
#endif

	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_ADJUST;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphAdjust;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphAdjust;
	type->validate = UxValidateXrtGphAdjust;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_ALIGN;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphAlign;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphAlign;
	type->validate = UxValidateXrtGphAlign;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_ANCHOR;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphAnchor;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphAnchor;
	type->validate = UxValidateXrtGphAnchor;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
		
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_ANGLEUNIT;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphAngleUnit;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphAngleUnit;
	type->validate = UxValidateXrtGphAngleUnit;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_BORDER;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphBorder;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphBorder;
	type->validate = UxValidateXrtGphBorder;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_DATA;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphData;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphData;
	type->validate = UxValidateXrtGphData;
	type->edit_func = UxPopupXrtData;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_DATA2;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphData2;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphData;
	type->validate = UxValidateXrtGphData;
	type->edit_func = UxPopupXrtData;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_DATASTYLE;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphDataStyle;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphDataStyle;
	type->validate = UxValidateString;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_DATASTYLES;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphDataStyles;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphDataStyles;
	type->validate = UxValidateString;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_MARKERMETHOD;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphMarkerMethod;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphMarkerMethod;
	type->validate = UxValidateString;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_PIEORDER;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphPieOrder;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphPieOrder;
	type->validate = UxValidateXrtGphPieOrder;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_PIETHRESHOLDMETHOD;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphPieThresholdMethod;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphPieThrMethod;
	type->validate = UxValidateXrtGphPieThrMethod;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_ROTATE;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphRotate;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphRotate;
	type->validate = UxValidateXrtGphRotate;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
		
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_SHADING;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphShading;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphShading;
	type->validate = UxValidateXrtGphShading;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_STRINGS;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphStrings;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphStrings;
	type->validate = UxValidateString;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_TIMEUNIT;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphTimeUnit;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphTimeUnit;
	type->validate = UxValidateXrtGphTimeUnit;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_TYPE;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphType;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphType;
	type->validate = UxValidateXrtGphType;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_VALUELABELS;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphValueLabels;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphValueLabels;
	type->validate = UxValidateString;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_ANNOTATIONMETHOD;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphAnnotationMethod;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphAnnotationMethod;
	type->validate = UxValidateXrtGphAnnotationMethod;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_ANNOPLACEMENT;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphAnnoPlacement;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphAnnoPlacement;
	type->validate = UxValidateXrtGphAnnoPlacement;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_ORIGINPLACEMENT;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphOriginPlacement;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphOriginPlacement;
	type->validate = UxValidateXrtGphOriginPlacement;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_NUMMETHOD;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphNumMethod;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphNumMethod;
	type->validate = UxValidateXrtGphNumMethod;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_BUBBLEMETHOD;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphBubbleMethod;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphBubbleMethod;
	type->validate = UxValidateXrtGphBubbleMethod;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;

	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_IMAGE;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphImage;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphImage;
	type->validate = UxValidateString;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;

	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_IMAGELAYOUT;
	type->utype = UxUT_string;
	type->xtype = UxXT_XrtGphImageLayout;
	type->convert_flag = 1;
	type->converter = NULL;
	type->values_of = UxValuesOfXrtGphImageLayout;
	type->validate = UxValidateXrtGphImageLayout;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;

	xrtgph_res_types = (XrtResourceType **)
		realloc(xrtgph_res_types, (n+2) * sizeof(XrtResourceType *));
	type = (XrtResourceType *) calloc (1, sizeof(XrtResourceType));
	type->datatype.type_graph = XRTGPH_VOIDFUNCTION;
	type->utype = UxUT_voidFunction;
	type->xtype = UxXT_String;
	type->convert_flag = 0;
	type->converter = NULL;
	type->values_of = UxValuesOfVoidFunction;
	type->validate = UxValidateVoidFunction;
	type->edit_func = NULL;
	type->get_func = NULL;
	type->put_func = NULL;
	xrtgph_res_types[n++] = type;
	
 	xrtgph_res_types[n] = NULL;
	numgph_res_types = n;
	AlreadyDone = TRUE;

}

static void
XrtGph_initialize_resources(table, nres, nres_string)
XrtGphResourceDesc	*table;
int					nres;
char				*nres_string;
{
	int		itype, n;
	char	buffer[128];
	
	for (n = 0; n < nres; n++) {
		itype = (int) table[n].res_type;
		table[n].type = xrtgph_res_types[itype];
		if (table[n].resnum != n) {
			sprintf(buffer,
					"XRT/graph res number %d & res table number %d unequal!",
					table[n].resnum, n);
			printf("%s\n", buffer);
		}
	}

}

void
XrtGph_init_resource_table()
{
	static Boolean	AlreadyDone = FALSE;

	if (AlreadyDone) {
		return;
	}
	
	XrtGph_init_resource_types();
	XrtGph_initialize_resources(xrtgph_res_table, numgph_res, "numgph_res");
	AlreadyDone = TRUE;
	
}

/* Float functions */

#ifdef DESIGN_TIME

static float
XrtGphGetFloat(sw, res)
swidget		sw;
Resource_t	*res;
{
	Widget		w;
	float		value  = (float) 0.0;
	char		*ptr;
	XtArgVal	argval;

	ptr = UxGetXtName(res);
	if (UxIsSwidget(sw))
		if ((w = UxGetWidget(sw)) != NULL)
			XtVaGetValues (w, ptr, &value, NULL);
		else
			if(UxFindValue(sw, res, &argval))
				value = XrtArgValToFloat(argval);

	return value;
}

static int
XrtGphPutFloat(sw, res, intvalue)
swidget		sw;
Resource_t	*res;
int			intvalue;
{
	Widget		w;
	char		*ptr;
	int			status = ERROR;
	XtArgVal	argval;
	FloatInt_t	localcast;
	float		value;

	localcast.i = intvalue;
	value = localcast.f;

	ptr = UxGetXtName(res);

	if (UxIsSwidget(sw)) {
		argval = XrtFloatToArgVal(value);
		UxSaveValue (sw, res, argval, FALSE);

		/*
		 ** If the delay flag is NOT set, update widget now (10/21/94 WJE)
		 */
		if (!UxGetDelay(sw) && (w = UxGetWidget(sw)) != NULL) {
			XtVaSetValues(w, ptr, argval, NULL);
		}

		status = NO_ERROR;
	}
	else {
		status = ERROR;
	}
	
	return(status);
}

#else

static float XrtGphGetFloat() {}
static int   XrtGphPutFloat() {}

#endif /* DESIGN_TIME */
