/*---------------------------------------------------------------------
 * $Source: /rcs/rcs2/include/pedit-aux.h,v $
 * $Date: 1996/11/09 16:24:15 $		$Revision: 2.5.65.1 $
 *---------------------------------------------------------------------
 *             Copyright 1990, Visual Edge Software Ltd.
 *
 * ALL  RIGHTS  RESERVED.  Permission  to  use,  copy,  modify,  and
 * distribute  this  software  and its documentation for any purpose
 * and  without  fee  is  hereby  granted,  provided  that the above
 * copyright  notice  appear  in  all  copies  and  that  both  that
 * copyright  notice and this permission notice appear in supporting
 * documentation,  and that  the name of Visual Edge Software not be
 * used  in advertising  or publicity  pertaining to distribution of
 * the software without specific, written prior permission. The year
 * included in the notice is the year of the creation of the work.
 *---------------------------------------------------------------------
 * Declarations for the property editor implemenation,
 * especially the PeSlot_t structure.
 *--------------------------------------------------------------------*/

#ifndef PEDITAUX_H
#define PEDITAUX_H

#include <resource.h>
#include "geometry.h"

/*-----------------------------------------------------------------------------
 * NAME:	PeSlot_t
 * DESCRIPTION:	
 *	The property editor uses PeSlot_t's to store description
 *	and state of each row in the editor.
 *---------------------------------------------------------------------------*/

typedef struct UxPeSlotStruct
{
	Widget		Row;		/* The visible row        */
	swidget		Editor;		/* Popup editor interface */

	Resource_t	* Resource;
	char*		Label;		/* From resource     */

	char*		Value;		/* From the swidgets */
	char*		NewValue;	/* From the user */
	int		Source;		/* From the swidgets */
	int		NewSource;	/* From the user     */
	Boolean		Lock;		/* From the swidgets */
	Boolean		NewLock;	/* From the user     */

	vhandle		NewParse;	/* During apply  */
	Boolean		ValueBad;	/* When validation fails  */

	char*		SrcLabel [3];   /* Default, public, private */

} PeSlot_t;


typedef enum {
	PE_CORE       = UxCORE,
	PE_SPECIFIC   = UxSPECIFIC,
	PE_CONSTRAINT = UxCONSTRAINT,
	PE_BEHAVIOR   = UxBEHAVIOR,
	PE_DECL	      = UxDECL,
	PE_COMPOUND   = UxCOMPOUND,
	PE_ALLRESOURCES = 6,
	PE_ALLPROPERTIES = 7,
	PE_NUM_CATEGORIES = 8,
	PE_DEFAULT = 9			/* Use UxPEInitCategory resource */
} ResCategory_t;


/*-----------------------------------------------------------------------------
 * Special Source codes.
 * These must be different from all SourceFlag_t values.
 *
 * SRC_UNKNOWN  - used in slot->Source when we need to re-evaluate it.
 * SRC_NOTEQUAL - no match among widgets, 
 * SRC_LOCK	- identifies LOCK entry in source option menu;
 * 		  must be different from ival.h RES_.... enumeration
 *
 * LOCK_UNKOWN	- used in slot->NewLock when not set by user.
 *		  must be different from True and False
 *---------------------------------------------------------------------------*/

#define SRC_NOTEQUAL  (-1)
#define SRC_UNKNOWN   (-2)
#define SRC_LOCK      (-3)

#define LOCK_UNKNOWN  (2)

/*-----------------------------------------------------------------------------
 * To handle all the rules for sensitivity of the option menus,
 * we keep the original Source and user-input NewSource separate,
 * the original Value and NewValue separate,
 * and the original Lock and NewLock separate.
 * NewValue is only assigned when the user makes a change
 * to keep strcopies to a minimum.
 *---------------------------------------------------------------------------*/

#define SourceChanged(slot) ((slot)->NewSource != SRC_UNKNOWN)
#define ValueChanged(slot)  ((slot)->NewValue  != NULL)
#define LockChanged(slot)   ((slot)->NewLock   != LOCK_UNKNOWN)
#define PendingChange(slot) (ValueChanged(slot) || \
			     SourceChanged(slot) || \
			     LockChanged(slot) || \
			     (slot)->ValueBad)

/*-----------------------------------------------------------------------------
 * Row functions used by the editor. 
 *---------------------------------------------------------------------------*/

extern Widget UxCreatePEditRow ();
extern void   UxRowSetup();

extern void UxRowDeferToPopup ();
extern void UxRowCancelEditor ();
extern void UxRowShowValue ();

/*-------------------------------------------------------------------
 * Anchor points for the row constraints. 
 * The name, value, and src fields are anchored on both sides,
 * so the row will grow to fit them all; this propagates
 * across all the rows in the property rowColumn 
 * to decide how wide the total layout becomes.
 *-----------------------------------------------------------------*/

#define FRACTION_BASE	200

#define NAME_RIGHT	58
#define VALUE_LEFT	65
#define VALUE_RIGHT	157
#define SRC_LEFT	168
#define COLUMN_OFFSET	2


/*-----------------------------------------------------
 * A little sweetener makes Motif taste better...
 *-----------------------------------------------------*/

#define Sensitize(w)       if (w) XtVaSetValues(w, XmNsensitive, True, NULL)
#define Insensitize(w)     if (w) XtVaSetValues(w, XmNsensitive, False, NULL)
#define Sensitivity(w,b)   if (w) XtVaSetValues(w, XmNsensitive, b, NULL)

/** Strictly for option menus **/

#define SensitizeOM(omw)     if (omw) do {\
	   XtVaSetValues(XmOptionButtonGadget(omw), XmNsensitive, True, NULL);\
	} while (0)

#define InsensitizeOM(omw)   if (omw) do {\
	   XtVaSetValues(XmOptionButtonGadget(omw), XmNsensitive, False, NULL);\
	} while (0)

/*-----------------------------------------------------------------------------
 * Cross-module definitions.
 *----------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------
 * THE way to get a property editor.
 * Single argument: a PList of swidgets, or NULL (for an empty editor).
 *----------------------------------------------------------------------------*/

extern swidget UxPopupPropertyEditor ();

extern void    UxPoolEditor ();
extern swidget UxCreatePropertyEditor ();
extern int     UxAddSwidgetList ();
extern PList_c * UxFilterRaisingEditors ();
Boolean UxToggleAutoLoad ();


/*-----------------------------------------------------
 * These use the CURRENT property editor context;
 * I.E they should be called in the flow of a callback,
 * or after pushing the context.
 *-----------------------------------------------------*/

extern int  UxPEConfirmLossIfAny ();

extern void UxShowVisibleRows (),
	    UxLoadValues (),
	    UxShowSwidgetList (),
	    UxUpdateEditor (),
	    UxSetEditCategory (),
	    UxUpdateAllCBEditors ();
#endif
